"""
Python module generated from Java source file org.bukkit.Registry

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.base import Predicates
from com.google.common.collect import ImmutableMap
from java.util import Iterator
from java.util import Objects
from java.util.function import Predicate
from java.util.stream import Stream
from java.util.stream import StreamSupport
from org.bukkit import *
from org.bukkit.advancement import Advancement
from org.bukkit.attribute import Attribute
from org.bukkit.block import Biome
from org.bukkit.block.banner import PatternType
from org.bukkit.boss import KeyedBossBar
from org.bukkit.damage import DamageType
from org.bukkit.enchantments import Enchantment
from org.bukkit.entity import Cat
from org.bukkit.entity import EntityType
from org.bukkit.entity import Frog
from org.bukkit.entity import Villager
from org.bukkit.entity.memory import MemoryKey
from org.bukkit.generator.structure import Structure
from org.bukkit.generator.structure import StructureType
from org.bukkit.inventory.meta.trim import TrimMaterial
from org.bukkit.inventory.meta.trim import TrimPattern
from org.bukkit.loot import LootTables
from org.bukkit.potion import PotionEffectType
from org.bukkit.potion import PotionType
from typing import Any, Callable, Iterable, Tuple


class Registry(Iterable):
    """
    Represents a registry of Bukkit objects that may be retrieved by
    NamespacedKey.
    
    Type `<T>`: type of item in the registry
    """

    ADVANCEMENT = Registry<Advancement>() {
    
        @Nullable
        @Override
        public Advancement get(@NotNull NamespacedKey key) {
            return Bukkit.getAdvancement(key);
        }
    
        @NotNull
        @Override
        public Stream<Advancement> stream() {
            return StreamSupport.stream(spliterator(), false);
        }
    
        @NotNull
        @Override
        public Iterator<Advancement> iterator() {
            return Bukkit.advancementIterator();
        }
    }
    """
    Server advancements.

    See
    - Bukkit.advancementIterator()
    """
    ART = SimpleRegistry<>(Art.class)
    """
    Server art.

    See
    - Art
    """
    ATTRIBUTE = SimpleRegistry<>(Attribute.class)
    """
    Attribute.

    See
    - Attribute
    """
    BANNER_PATTERN = SimpleRegistry<>(PatternType.class)
    """
    Server banner patterns.

    See
    - PatternType
    """
    BIOME = SimpleRegistry<>(Biome.class)
    """
    Server biomes.

    See
    - Biome
    """
    BOSS_BARS = Registry<KeyedBossBar>() {
    
        @Nullable
        @Override
        public KeyedBossBar get(@NotNull NamespacedKey key) {
            return Bukkit.getBossBar(key);
        }
    
        @NotNull
        @Override
        public Stream<KeyedBossBar> stream() {
            return StreamSupport.stream(spliterator(), false);
        }
    
        @NotNull
        @Override
        public Iterator<KeyedBossBar> iterator() {
            return Bukkit.getBossBars();
        }
    }
    """
    Custom boss bars.

    See
    - Bukkit.getBossBars()
    """
    CAT_VARIANT = SimpleRegistry<>(Cat.Type.class)
    """
    Server cat types.

    See
    - Cat.Type
    """
    ENCHANTMENT = Objects.requireNonNull(Bukkit.getRegistry(Enchantment.class), "No registry present for Enchantment. This is a bug.")
    """
    Server enchantments.

    See
    - Enchantment
    """
    ENTITY_TYPE = SimpleRegistry<>(EntityType.class, (entity) -> entity != EntityType.UNKNOWN)
    """
    Server entity types.

    See
    - EntityType
    """
    INSTRUMENT = Objects.requireNonNull(Bukkit.getRegistry(MusicInstrument.class), "No registry present for MusicInstrument. This is a bug.")
    """
    Server instruments.

    See
    - MusicInstrument
    """
    LOOT_TABLES = SimpleRegistry<>(LootTables.class)
    """
    Default server loot tables.

    See
    - LootTables
    """
    MATERIAL = SimpleRegistry<>(Material.class, (mat) -> !mat.isLegacy())
    """
    Server materials.

    See
    - Material
    """
    EFFECT = Objects.requireNonNull(Bukkit.getRegistry(PotionEffectType.class), "No registry present for PotionEffectType. This is a bug.")
    """
    Server mob effects.

    See
    - PotionEffectType
    """
    PARTICLE_TYPE = SimpleRegistry<>(Particle.class, (par) -> par.register)
    """
    Server particles.

    See
    - Particle
    """
    POTION = SimpleRegistry<>(PotionType.class)
    """
    Server potions.

    See
    - PotionType
    """
    STATISTIC = SimpleRegistry<>(Statistic.class)
    """
    Server statistics.

    See
    - Statistic
    """
    STRUCTURE = Bukkit.getRegistry(Structure.class)
    """
    Server structures.

    See
    - Structure
    """
    STRUCTURE_TYPE = Bukkit.getRegistry(StructureType.class)
    """
    Server structure types.

    See
    - StructureType
    """
    SOUNDS = SimpleRegistry<>(Sound.class)
    """
    Sound keys.

    See
    - Sound
    """
    TRIM_MATERIAL = Bukkit.getRegistry(TrimMaterial.class)
    """
    Trim materials.

    See
    - TrimMaterial
    """
    TRIM_PATTERN = Bukkit.getRegistry(TrimPattern.class)
    """
    Trim patterns.

    See
    - TrimPattern
    """
    DAMAGE_TYPE = Objects.requireNonNull(Bukkit.getRegistry(DamageType.class), "No registry present for DamageType. This is a bug.")
    """
    Damage types.

    See
    - DamageType
    """
    VILLAGER_PROFESSION = SimpleRegistry<>(Villager.Profession.class)
    """
    Villager profession.

    See
    - Villager.Profession
    """
    VILLAGER_TYPE = SimpleRegistry<>(Villager.Type.class)
    """
    Villager type.

    See
    - Villager.Type
    """
    MEMORY_MODULE_TYPE = Registry<MemoryKey>() {
    
        @NotNull
        @Override
        public Iterator iterator() {
            return MemoryKey.values().iterator();
        }
    
        @Nullable
        @Override
        public MemoryKey get(@NotNull NamespacedKey key) {
            return MemoryKey.getByKey(key);
        }
    
        @NotNull
        @Override
        public Stream<MemoryKey> stream() {
            return StreamSupport.stream(spliterator(), false);
        }
    }
    """
    Memory Keys.

    See
    - MemoryKey
    """
    FLUID = SimpleRegistry<>(Fluid.class)
    """
    Server fluids.

    See
    - Fluid
    """
    FROG_VARIANT = SimpleRegistry<>(Frog.Variant.class)
    """
    Frog variants.

    See
    - Frog.Variant
    """
    GAME_EVENT = Objects.requireNonNull(Bukkit.getRegistry(GameEvent.class), "No registry present for GameEvent. This is a bug.")
    """
    Game events.

    See
    - GameEvent
    """


    def get(self, key: "NamespacedKey") -> "T":
        """
        Get the object by its key.

        Arguments
        - key: non-null key

        Returns
        - item or null if does not exist
        """
        ...


    def stream(self) -> "Stream"["T"]:
        """
        Returns a new stream, which contains all registry items, which are registered to the registry.

        Returns
        - a stream of all registry items
        """
        ...


    def match(self, input: str) -> "T":
        """
        Attempts to match the registered object with the given key.
        
        This will attempt to find a reasonable match based on the provided input
        and may do so through unspecified means.

        Arguments
        - input: non-null input

        Returns
        - registered object or null if does not exist
        """
        ...



"""
Python module generated from Java source file org.bukkit.MusicInstrument

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.collect import Lists
from java.util import Collections
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class MusicInstrument(Keyed):

    PONDER = getInstrument("ponder_goat_horn")
    SING = getInstrument("sing_goat_horn")
    SEEK = getInstrument("seek_goat_horn")
    FEEL = getInstrument("feel_goat_horn")
    ADMIRE = getInstrument("admire_goat_horn")
    CALL = getInstrument("call_goat_horn")
    YEARN = getInstrument("yearn_goat_horn")
    DREAM = getInstrument("dream_goat_horn")


    @staticmethod
    def getByKey(namespacedKey: "NamespacedKey") -> "MusicInstrument":
        """
        Returns a MusicInstrument by a NamespacedKey.

        Arguments
        - namespacedKey: the key

        Returns
        - the event or null

        Deprecated
        - Use Registry.get(NamespacedKey) instead.
        """
        ...


    @staticmethod
    def values() -> Iterable["MusicInstrument"]:
        """
        Returns all known MusicInstruments.

        Returns
        - the memoryKeys

        Deprecated
        - use Registry.iterator().
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.tokens.TagToken

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.tokens import *
from typing import Any, Callable, Iterable, Tuple


class TagToken(Token):

    def __init__(self, value: "TagTuple", startMark: "Mark", endMark: "Mark"):
        ...


    def getValue(self) -> "TagTuple":
        ...


    def getTokenId(self) -> "Token.ID":
        ...



from .Tripwire import Tripwire
from .Jigsaw import Jigsaw
from .TrialSpawner import TrialSpawner
from .Slab import Slab
from .Lectern import Lectern
from .RedstoneWallTorch import RedstoneWallTorch
from .Campfire import Campfire
from .SculkCatalyst import SculkCatalyst
from .TechnicalPiston import TechnicalPiston
from .BubbleColumn import BubbleColumn
from .TripwireHook import TripwireHook
from .PointedDripstone import PointedDripstone
from .CaveVines import CaveVines
from .Sapling import Sapling
from .Barrel import Barrel
from .Switch import Switch
from .Chain import Chain
from .Beehive import Beehive
from .TNT import TNT
from .Fence import Fence
from .Candle import Candle
from .Crafter import Crafter
from .Chest import Chest
from .ChiseledBookshelf import ChiseledBookshelf
from .SculkSensor import SculkSensor
from .SmallDripleaf import SmallDripleaf
from .EnderChest import EnderChest
from .WallSign import WallSign
from .SculkShrieker import SculkShrieker
from .Fire import Fire
from .RedstoneRail import RedstoneRail
from .BrewingStand import BrewingStand
from .GlassPane import GlassPane
from .Farmland import Farmland
from .Observer import Observer
from .BigDripleaf import BigDripleaf
from .RedstoneWire import RedstoneWire
from .Comparator import Comparator
from .LightningRod import LightningRod
from .GlowLichen import GlowLichen
from .CommandBlock import CommandBlock
from .Cocoa import Cocoa
from .CopperBulb import CopperBulb
from .NoteBlock import NoteBlock
from .MangrovePropagule import MangrovePropagule
from .StructureBlock import StructureBlock
from .DecoratedPot import DecoratedPot
from .Hopper import Hopper
from .Grindstone import Grindstone
from .Snow import Snow
from .CoralWallFan import CoralWallFan
from .Lantern import Lantern
from .EndPortalFrame import EndPortalFrame
from .Dispenser import Dispenser
from .Stairs import Stairs
from .Repeater import Repeater
from .Bell import Bell
from .SeaPickle import SeaPickle
from .PitcherCrop import PitcherCrop
from .Wall import Wall
from .PinkPetals import PinkPetals
from .Jukebox import Jukebox
from .Bed import Bed
from .Sign import Sign
from .WallHangingSign import WallHangingSign
from .SculkVein import SculkVein
from .PistonHead import PistonHead
from .Gate import Gate
from .Scaffolding import Scaffolding
from .Light import Light
from .RespawnAnchor import RespawnAnchor
from .Cake import Cake
from .HangingSign import HangingSign
from .Bamboo import Bamboo
from .CalibratedSculkSensor import CalibratedSculkSensor
from .Leaves import Leaves
from .Furnace import Furnace
from .CaveVinesPlant import CaveVinesPlant
from .Piston import Piston
from .TurtleEgg import TurtleEgg
from .AmethystCluster import AmethystCluster
from .TrapDoor import TrapDoor
from .DaylightDetector import DaylightDetector
from .Ladder import Ladder
from .Dripleaf import Dripleaf
from .Door import Door


"""
Python module generated from Java source file com.google.gson.GsonBuilder

Java source file obtained from artifact gson version 2.10.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.annotations import Since
from com.google.gson.annotations import Until
from com.google.gson.internal import $Gson$Preconditions
from com.google.gson.internal import Excluder
from com.google.gson.internal.bind import DefaultDateTypeAdapter
from com.google.gson.internal.bind import TreeTypeAdapter
from com.google.gson.internal.bind import TypeAdapters
from com.google.gson.internal.sql import SqlTypesSupport
from com.google.gson.reflect import TypeToken
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonWriter
from java.lang.reflect import Type
from java.text import DateFormat
from java.util import Collections
from java.util import Date
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class GsonBuilder:
    """
    Use this builder to construct a Gson instance when you need to set configuration
    options other than the default. For Gson with default configuration, it is simpler to
    use `new Gson()`. `GsonBuilder` is best used by creating it, and then invoking its
    various configuration methods, and finally calling create.
    
    The following is an example shows how to use the `GsonBuilder` to construct a Gson
    instance:
    
    ```
    Gson gson = new GsonBuilder()
        .registerTypeAdapter(Id.class, new IdTypeAdapter())
        .enableComplexMapKeySerialization()
        .serializeNulls()
        .setDateFormat(DateFormat.LONG)
        .setFieldNamingPolicy(FieldNamingPolicy.UPPER_CAMEL_CASE)
        .setPrettyPrinting()
        .setVersion(1.0)
        .create();
    ```
    
    NOTES:
    
    -  the order of invocation of configuration methods does not matter.
    -  The default serialization of Date and its subclasses in Gson does
     not contain time-zone information. So, if you are using date/time instances,
     use `GsonBuilder` and its `setDateFormat` methods.

    Author(s)
    - Jesse Wilson
    """

    def __init__(self):
        """
        Creates a GsonBuilder instance that can be used to build Gson with various configuration
        settings. GsonBuilder follows the builder pattern, and it is typically used by first
        invoking various configuration methods to set desired options, and finally calling
        .create().
        """
        ...


    def setVersion(self, version: float) -> "GsonBuilder":
        """
        Configures Gson to enable versioning support. Versioning support works based on the
        annotation types Since and Until. It allows including or excluding fields
        and classes based on the specified version. See the documentation of these annotation
        types for more information.
        
        By default versioning support is disabled and usage of `@Since` and `@Until`
        has no effect.

        Arguments
        - version: the version number to use.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Raises
        - IllegalArgumentException: if the version number is NaN or negative

        See
        - Until
        """
        ...


    def excludeFieldsWithModifiers(self, *modifiers: Tuple[int, ...]) -> "GsonBuilder":
        """
        Configures Gson to excludes all class fields that have the specified modifiers. By default,
        Gson will exclude all fields marked `transient` or `static`. This method will
        override that behavior.
        
        This is a convenience method which behaves as if an ExclusionStrategy which
        excludes these fields was .setExclusionStrategies(ExclusionStrategy...) registered with this builder.

        Arguments
        - modifiers: the field modifiers. You must use the modifiers specified in the
        java.lang.reflect.Modifier class. For example,
        java.lang.reflect.Modifier.TRANSIENT,
        java.lang.reflect.Modifier.STATIC.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern
        """
        ...


    def generateNonExecutableJson(self) -> "GsonBuilder":
        """
        Makes the output JSON non-executable in Javascript by prefixing the generated JSON with some
        special text. This prevents attacks from third-party sites through script sourcing. See
        <a href="http://code.google.com/p/google-gson/issues/detail?id=42">Gson Issue 42</a>
        for details.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.3
        """
        ...


    def excludeFieldsWithoutExposeAnnotation(self) -> "GsonBuilder":
        """
        Configures Gson to exclude all fields from consideration for serialization and deserialization
        that do not have the com.google.gson.annotations.Expose annotation.
        
        This is a convenience method which behaves as if an ExclusionStrategy which excludes
        these fields was .setExclusionStrategies(ExclusionStrategy...) registered with this builder.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern
        """
        ...


    def serializeNulls(self) -> "GsonBuilder":
        """
        Configure Gson to serialize null fields. By default, Gson omits all fields that are null
        during serialization.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.2
        """
        ...


    def enableComplexMapKeySerialization(self) -> "GsonBuilder":
        """
        Enabling this feature will only change the serialized form if the map key is
        a complex type (i.e. non-primitive) in its <strong>serialized</strong> JSON
        form. The default implementation of map serialization uses `toString()`
        on the key; however, when this is called then one of the following cases
        apply:
        
        **Maps as JSON objects**
        
        For this case, assume that a type adapter is registered to serialize and
        deserialize some `Point` class, which contains an x and y coordinate,
        to/from the JSON Primitive string value `"(x,y)"`. The Java map would
        then be serialized as a JsonObject.
        
        Below is an example:
        ```  `Gson gson = new GsonBuilder()
              .register(Point.class, new MyPointTypeAdapter())
              .enableComplexMapKeySerialization()
              .create();
        
          Map<Point, String> original = new LinkedHashMap<>();
          original.put(new Point(5, 6), "a");
          original.put(new Point(8, 8), "b");
          System.out.println(gson.toJson(original, type));````
        The above code prints this JSON object:```  `{
            "(5,6)": "a",
            "(8,8)": "b"`
        }```
        
        **Maps as JSON arrays**
        
        For this case, assume that a type adapter was NOT registered for some
        `Point` class, but rather the default Gson serialization is applied.
        In this case, some `new Point(2,3)` would serialize as `{"x":2,"y":3`}.
        
        Given the assumption above, a `Map<Point, String>` will be
        serialize as an array of arrays (can be viewed as an entry set of pairs).
        
        Below is an example of serializing complex types as JSON arrays:
        ``` `Gson gson = new GsonBuilder()
              .enableComplexMapKeySerialization()
              .create();
        
          Map<Point, String> original = new LinkedHashMap<>();
          original.put(new Point(5, 6), "a");
          original.put(new Point(8, 8), "b");
          System.out.println(gson.toJson(original, type));`
        ```
        
        The JSON output would look as follows:
        ```   `[
            [
              {
                "x": 5,
                "y": 6`,
              "a"
            ],
            [
              {
                "x": 8,
                "y": 8
              },
              "b"
            ]
          ]
        }```

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.7
        """
        ...


    def disableInnerClassSerialization(self) -> "GsonBuilder":
        """
        Configures Gson to exclude inner classes (= non-`static` nested classes) during serialization
        and deserialization. This is a convenience method which behaves as if an ExclusionStrategy
        which excludes inner classes was .setExclusionStrategies(ExclusionStrategy...) registered with this builder.
        This means inner classes will be serialized as JSON `null`, and will be deserialized as
        Java `null` with their JSON data being ignored. And fields with an inner class as type will
        be ignored during serialization and deserialization.
        
        By default Gson serializes and deserializes inner classes, but ignores references to the
        enclosing instance. Deserialization might not be possible at all when .disableJdkUnsafe()
        is used (and no custom InstanceCreator is registered), or it can lead to unexpected
        `NullPointerException`s when the deserialized instance is used afterwards.
        
        In general using inner classes with Gson should be avoided; they should be converted to `static`
        nested classes if possible.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.3
        """
        ...


    def setLongSerializationPolicy(self, serializationPolicy: "LongSerializationPolicy") -> "GsonBuilder":
        """
        Configures Gson to apply a specific serialization policy for `Long` and `long`
        objects.

        Arguments
        - serializationPolicy: the particular policy to use for serializing longs.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.3
        """
        ...


    def setFieldNamingPolicy(self, namingConvention: "FieldNamingPolicy") -> "GsonBuilder":
        """
        Configures Gson to apply a specific naming policy to an object's fields during serialization
        and deserialization.
        
        This method just delegates to .setFieldNamingStrategy(FieldNamingStrategy).
        """
        ...


    def setFieldNamingStrategy(self, fieldNamingStrategy: "FieldNamingStrategy") -> "GsonBuilder":
        """
        Configures Gson to apply a specific naming strategy to an object's fields during
        serialization and deserialization.
        
        The created Gson instance might only use the field naming strategy once for a
        field and cache the result. It is not guaranteed that the strategy will be used
        again every time the value of a field is serialized or deserialized.

        Arguments
        - fieldNamingStrategy: the naming strategy to apply to the fields

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.3
        """
        ...


    def setObjectToNumberStrategy(self, objectToNumberStrategy: "ToNumberStrategy") -> "GsonBuilder":
        """
        Configures Gson to apply a specific number strategy during deserialization of Object.

        Arguments
        - objectToNumberStrategy: the actual object-to-number strategy

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        See
        - ToNumberPolicy.DOUBLE The default object-to-number strategy

        Since
        - 2.8.9
        """
        ...


    def setNumberToNumberStrategy(self, numberToNumberStrategy: "ToNumberStrategy") -> "GsonBuilder":
        """
        Configures Gson to apply a specific number strategy during deserialization of Number.

        Arguments
        - numberToNumberStrategy: the actual number-to-number strategy

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        See
        - ToNumberPolicy.LAZILY_PARSED_NUMBER The default number-to-number strategy

        Since
        - 2.8.9
        """
        ...


    def setExclusionStrategies(self, *strategies: Tuple["ExclusionStrategy", ...]) -> "GsonBuilder":
        """
        Configures Gson to apply a set of exclusion strategies during both serialization and
        deserialization. Each of the `strategies` will be applied as a disjunction rule.
        This means that if one of the `strategies` suggests that a field (or class) should be
        skipped then that field (or object) is skipped during serialization/deserialization.
        The strategies are added to the existing strategies (if any); the existing strategies
        are not replaced.
        
        Fields are excluded for serialization and deserialization when
        ExclusionStrategy.shouldSkipField(FieldAttributes) shouldSkipField returns `True`,
        or when ExclusionStrategy.shouldSkipClass(Class) shouldSkipClass returns `True`
        for the field type. Gson behaves as if the field did not exist; its value is not serialized
        and on deserialization if a JSON member with this name exists it is skipped by default.
        When objects of an excluded type (as determined by
        ExclusionStrategy.shouldSkipClass(Class) shouldSkipClass) are serialized a
        JSON null is written to output, and when deserialized the JSON value is skipped and
        `null` is returned.
        
        The created Gson instance might only use an exclusion strategy once for a field or
        class and cache the result. It is not guaranteed that the strategy will be used again
        every time the value of a field or a class is serialized or deserialized.

        Arguments
        - strategies: the set of strategy object to apply during object (de)serialization.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.4
        """
        ...


    def addSerializationExclusionStrategy(self, strategy: "ExclusionStrategy") -> "GsonBuilder":
        """
        Configures Gson to apply the passed in exclusion strategy during serialization.
        If this method is invoked numerous times with different exclusion strategy objects
        then the exclusion strategies that were added will be applied as a disjunction rule.
        This means that if one of the added exclusion strategies suggests that a field (or
        class) should be skipped then that field (or object) is skipped during its
        serialization.
        
        See the documentation of .setExclusionStrategies(ExclusionStrategy...)
        for a detailed description of the effect of exclusion strategies.

        Arguments
        - strategy: an exclusion strategy to apply during serialization.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.7
        """
        ...


    def addDeserializationExclusionStrategy(self, strategy: "ExclusionStrategy") -> "GsonBuilder":
        """
        Configures Gson to apply the passed in exclusion strategy during deserialization.
        If this method is invoked numerous times with different exclusion strategy objects
        then the exclusion strategies that were added will be applied as a disjunction rule.
        This means that if one of the added exclusion strategies suggests that a field (or
        class) should be skipped then that field (or object) is skipped during its
        deserialization.
        
        See the documentation of .setExclusionStrategies(ExclusionStrategy...)
        for a detailed description of the effect of exclusion strategies.

        Arguments
        - strategy: an exclusion strategy to apply during deserialization.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.7
        """
        ...


    def setPrettyPrinting(self) -> "GsonBuilder":
        """
        Configures Gson to output Json that fits in a page for pretty printing. This option only
        affects Json serialization.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern
        """
        ...


    def setLenient(self) -> "GsonBuilder":
        """
        Configures Gson to allow JSON data which does not strictly comply with the JSON specification.
        
        Note: Due to legacy reasons most methods of Gson are always lenient, regardless of
        whether this builder method is used.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        See
        - JsonWriter.setLenient(boolean)
        """
        ...


    def disableHtmlEscaping(self) -> "GsonBuilder":
        """
        By default, Gson escapes HTML characters such as &lt; &gt; etc. Use this option to configure
        Gson to pass-through HTML characters as is.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.3
        """
        ...


    def setDateFormat(self, pattern: str) -> "GsonBuilder":
        """
        Configures Gson to serialize `Date` objects according to the pattern provided. You can
        call this method or .setDateFormat(int) multiple times, but only the last invocation
        will be used to decide the serialization format.
        
        The date format will be used to serialize and deserialize java.util.Date and in case
        the `java.sql` module is present, also java.sql.Timestamp and java.sql.Date.
        
        Note that this pattern must abide by the convention provided by `SimpleDateFormat`
        class. See the documentation in java.text.SimpleDateFormat for more information on
        valid date and time patterns.

        Arguments
        - pattern: the pattern that dates will be serialized/deserialized to/from

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.2
        """
        ...


    def setDateFormat(self, style: int) -> "GsonBuilder":
        """
        Configures Gson to to serialize `Date` objects according to the style value provided.
        You can call this method or .setDateFormat(String) multiple times, but only the last
        invocation will be used to decide the serialization format.
        
        Note that this style value should be one of the predefined constants in the
        `DateFormat` class. See the documentation in java.text.DateFormat for more
        information on the valid style constants.

        Arguments
        - style: the predefined date style that date objects will be serialized/deserialized
        to/from

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.2
        """
        ...


    def setDateFormat(self, dateStyle: int, timeStyle: int) -> "GsonBuilder":
        """
        Configures Gson to to serialize `Date` objects according to the style value provided.
        You can call this method or .setDateFormat(String) multiple times, but only the last
        invocation will be used to decide the serialization format.
        
        Note that this style value should be one of the predefined constants in the
        `DateFormat` class. See the documentation in java.text.DateFormat for more
        information on the valid style constants.

        Arguments
        - dateStyle: the predefined date style that date objects will be serialized/deserialized
        to/from
        - timeStyle: the predefined style for the time portion of the date objects

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.2
        """
        ...


    def registerTypeAdapter(self, type: "Type", typeAdapter: "Object") -> "GsonBuilder":
        """
        Configures Gson for custom serialization or deserialization. This method combines the
        registration of an TypeAdapter, InstanceCreator, JsonSerializer, and a
        JsonDeserializer. It is best used when a single object `typeAdapter` implements
        all the required interfaces for custom serialization with Gson. If a type adapter was
        previously registered for the specified `type`, it is overwritten.
        
        This registers the type specified and no other types: you must manually register related
        types! For example, applications registering `boolean.class` should also register `Boolean.class`.
        
        JsonSerializer and JsonDeserializer are made "`null`-safe". This
        means when trying to serialize `null`, Gson will write a JSON `null` and the
        serializer is not called. Similarly when deserializing a JSON `null`, Gson will emit
        `null` without calling the deserializer. If it is desired to handle `null` values,
        a TypeAdapter should be used instead.

        Arguments
        - type: the type definition for the type adapter being registered
        - typeAdapter: This object must implement at least one of the TypeAdapter,
        InstanceCreator, JsonSerializer, and a JsonDeserializer interfaces.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern
        """
        ...


    def registerTypeAdapterFactory(self, factory: "TypeAdapterFactory") -> "GsonBuilder":
        """
        Register a factory for type adapters. Registering a factory is useful when the type
        adapter needs to be configured based on the type of the field being processed. Gson
        is designed to handle a large number of factories, so you should consider registering
        them to be at par with registering an individual type adapter.
        
        The created Gson instance might only use the factory once to create an adapter for
        a specific type and cache the result. It is not guaranteed that the factory will be used
        again every time the type is serialized or deserialized.

        Since
        - 2.1
        """
        ...


    def registerTypeHierarchyAdapter(self, baseType: type[Any], typeAdapter: "Object") -> "GsonBuilder":
        """
        Configures Gson for custom serialization or deserialization for an inheritance type hierarchy.
        This method combines the registration of a TypeAdapter, JsonSerializer and
        a JsonDeserializer. If a type adapter was previously registered for the specified
        type hierarchy, it is overridden. If a type adapter is registered for a specific type in
        the type hierarchy, it will be invoked instead of the one registered for the type hierarchy.

        Arguments
        - baseType: the class definition for the type adapter being registered for the base class
               or interface
        - typeAdapter: This object must implement at least one of TypeAdapter,
               JsonSerializer or JsonDeserializer interfaces.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.7
        """
        ...


    def serializeSpecialFloatingPointValues(self) -> "GsonBuilder":
        """
        Section 2.4 of <a href="http://www.ietf.org/rfc/rfc4627.txt">JSON specification</a> disallows
        special double values (NaN, Infinity, -Infinity). However,
        <a href="http://www.ecma-international.org/publications/files/ECMA-ST/Ecma-262.pdf">Javascript
        specification</a> (see section 4.3.20, 4.3.22, 4.3.23) allows these values as valid Javascript
        values. Moreover, most JavaScript engines will accept these special values in JSON without
        problem. So, at a practical level, it makes sense to accept these values as valid JSON even
        though JSON specification disallows them.
        
        Gson always accepts these special values during deserialization. However, it outputs
        strictly compliant JSON. Hence, if it encounters a float value Float.NaN,
        Float.POSITIVE_INFINITY, Float.NEGATIVE_INFINITY, or a double value
        Double.NaN, Double.POSITIVE_INFINITY, Double.NEGATIVE_INFINITY, it
        will throw an IllegalArgumentException. This method provides a way to override the
        default behavior when you know that the JSON receiver will be able to handle these special
        values.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 1.3
        """
        ...


    def disableJdkUnsafe(self) -> "GsonBuilder":
        """
        Disables usage of JDK's `sun.misc.Unsafe`.
        
        By default Gson uses `Unsafe` to create instances of classes which don't have
        a no-args constructor. However, `Unsafe` might not be available for all Java
        runtimes. For example Android does not provide `Unsafe`, or only with limited
        functionality. Additionally `Unsafe` creates instances without executing any
        constructor or initializer block, or performing initialization of field values. This can
        lead to surprising and difficult to debug errors.
        Therefore, to get reliable behavior regardless of which runtime is used, and to detect
        classes which cannot be deserialized in an early stage of development, this method allows
        disabling usage of `Unsafe`.

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 2.9.0
        """
        ...


    def addReflectionAccessFilter(self, filter: "ReflectionAccessFilter") -> "GsonBuilder":
        """
        Adds a reflection access filter. A reflection access filter prevents Gson from using
        reflection for the serialization and deserialization of certain classes. The logic in
        the filter specifies which classes those are.
        
        Filters will be invoked in reverse registration order, that is, the most recently
        added filter will be invoked first.
        
        By default Gson has no filters configured and will try to use reflection for
        all classes for which no TypeAdapter has been registered, and for which no
        built-in Gson `TypeAdapter` exists.
        
        The created Gson instance might only use an access filter once for a class or its
        members and cache the result. It is not guaranteed that the filter will be used again
        every time a class or its members are accessed during serialization or deserialization.

        Arguments
        - filter: filter to add

        Returns
        - a reference to this `GsonBuilder` object to fulfill the "Builder" pattern

        Since
        - 2.9.1
        """
        ...


    def create(self) -> "Gson":
        """
        Creates a Gson instance based on the current configuration. This method is free of
        side-effects to this `GsonBuilder` instance and hence can be called multiple times.

        Returns
        - an instance of Gson configured with the options currently set in this builder
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Villager

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.util import Locale
from org.bukkit import Keyed
from org.bukkit import Location
from org.bukkit import NamespacedKey
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Villager(AbstractVillager):
    """
    Represents a villager NPC
    """

    def getProfession(self) -> "Profession":
        """
        Gets the current profession of this villager.

        Returns
        - Current profession.
        """
        ...


    def setProfession(self, profession: "Profession") -> None:
        """
        Sets the new profession of this villager.

        Arguments
        - profession: New profession.
        """
        ...


    def getVillagerType(self) -> "Type":
        """
        Gets the current type of this villager.

        Returns
        - Current type.
        """
        ...


    def setVillagerType(self, type: "Type") -> None:
        """
        Sets the new type of this villager.

        Arguments
        - type: New type.
        """
        ...


    def getVillagerLevel(self) -> int:
        """
        Gets the level of this villager.
        
        A villager with a level of 1 and no experience is liable to lose its
        profession.

        Returns
        - this villager's level
        """
        ...


    def setVillagerLevel(self, level: int) -> None:
        """
        Sets the level of this villager.
        
        A villager with a level of 1 and no experience is liable to lose its
        profession.

        Arguments
        - level: the new level

        Raises
        - IllegalArgumentException: if level not between [1, 5]
        """
        ...


    def getVillagerExperience(self) -> int:
        """
        Gets the trading experience of this villager.

        Returns
        - trading experience
        """
        ...


    def setVillagerExperience(self, experience: int) -> None:
        """
        Sets the trading experience of this villager.

        Arguments
        - experience: new experience

        Raises
        - IllegalArgumentException: if experience &lt; 0
        """
        ...


    def sleep(self, location: "Location") -> bool:
        """
        Attempts to make this villager sleep at the given location.
        
        The location must be in the current world and have a bed placed at the
        location. The villager will put its head on the specified block while
        sleeping.

        Arguments
        - location: the location of the bed

        Returns
        - whether the sleep was successful
        """
        ...


    def wakeup(self) -> None:
        """
        Causes this villager to wake up if he's currently sleeping.

        Raises
        - IllegalStateException: if not sleeping
        """
        ...


    def shakeHead(self) -> None:
        """
        Causes this villager to shake his head.
        """
        ...


    def zombify(self) -> "ZombieVillager":
        """
        Convert this Villager into a ZombieVillager as if it was killed by a
        Zombie.
        
        **Note:** this will fire a EntityTransformEvent

        Returns
        - the converted entity ZombieVillager or null if the
        conversion its cancelled
        """
        ...


    class Type(Enum):
        """
        Represents Villager type, usually corresponding to what biome they spawn
        in.
        """

        DESERT = 0
        JUNGLE = 1
        PLAINS = 2
        SAVANNA = 3
        SNOW = 4
        SWAMP = 5
        TAIGA = 6


        def getKey(self) -> "NamespacedKey":
            ...


    class Profession(Enum):
        """
        Represents the various different Villager professions there may be.
        Villagers have different trading options depending on their profession,
        """

        NONE = 0
        ARMORER = 1
        """
        Armorer profession. Wears a black apron. Armorers primarily trade for
        iron armor, chainmail armor, and sometimes diamond armor.
        """
        BUTCHER = 2
        """
        Butcher profession. Wears a white apron. Butchers primarily trade for
        raw and cooked food.
        """
        CARTOGRAPHER = 3
        """
        Cartographer profession. Wears a white robe. Cartographers primarily
        trade for explorer maps and some paper.
        """
        CLERIC = 4
        """
        Cleric profession. Wears a purple robe. Clerics primarily trade for
        rotten flesh, gold ingot, redstone, lapis, ender pearl, glowstone,
        and bottle o' enchanting.
        """
        FARMER = 5
        """
        Farmer profession. Wears a brown robe. Farmers primarily trade for
        food-related items.
        """
        FISHERMAN = 6
        """
        Fisherman profession. Wears a brown robe. Fisherman primarily trade
        for fish, as well as possibly selling string and/or coal.
        """
        FLETCHER = 7
        """
        Fletcher profession. Wears a brown robe. Fletchers primarily trade
        for string, bows, and arrows.
        """
        LEATHERWORKER = 8
        """
        Leatherworker profession. Wears a white apron. Leatherworkers
        primarily trade for leather, and leather armor, as well as saddles.
        """
        LIBRARIAN = 9
        """
        Librarian profession. Wears a white robe. Librarians primarily trade
        for paper, books, and enchanted books.
        """
        MASON = 10
        """
        Mason profession.
        """
        NITWIT = 11
        """
        Nitwit profession. Wears a green apron, cannot trade. Nitwit
        villagers do not do anything. They do not have any trades by default.
        """
        SHEPHERD = 12
        """
        Sheperd profession. Wears a brown robe. Shepherds primarily trade for
        wool items, and shears.
        """
        TOOLSMITH = 13
        """
        Toolsmith profession. Wears a black apron. Tool smiths primarily
        trade for iron and diamond tools.
        """
        WEAPONSMITH = 14
        """
        Weaponsmith profession. Wears a black apron. Weapon smiths primarily
        trade for iron and diamond weapons, sometimes enchanted.
        """


        def getKey(self) -> "NamespacedKey":
            ...



"""
Python module generated from Java source file org.bukkit.map.MapCursor

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.map import *
from typing import Any, Callable, Iterable, Tuple


class MapCursor:
    """
    Represents a cursor on a map.
    """

    def __init__(self, x: int, y: int, direction: int, type: int, visible: bool):
        """
        Initialize the map cursor.

        Arguments
        - x: The x coordinate, from -128 to 127.
        - y: The y coordinate, from -128 to 127.
        - direction: The facing of the cursor, from 0 to 15.
        - type: The type (color/style) of the map cursor.
        - visible: Whether the cursor is visible by default.

        Deprecated
        - Magic value
        """
        ...


    def __init__(self, x: int, y: int, direction: int, type: "Type", visible: bool):
        """
        Initialize the map cursor.

        Arguments
        - x: The x coordinate, from -128 to 127.
        - y: The y coordinate, from -128 to 127.
        - direction: The facing of the cursor, from 0 to 15.
        - type: The type (color/style) of the map cursor.
        - visible: Whether the cursor is visible by default.
        """
        ...


    def __init__(self, x: int, y: int, direction: int, type: int, visible: bool, caption: str):
        """
        Initialize the map cursor.

        Arguments
        - x: The x coordinate, from -128 to 127.
        - y: The y coordinate, from -128 to 127.
        - direction: The facing of the cursor, from 0 to 15.
        - type: The type (color/style) of the map cursor.
        - visible: Whether the cursor is visible by default.
        - caption: cursor caption

        Deprecated
        - Magic value
        """
        ...


    def __init__(self, x: int, y: int, direction: int, type: "Type", visible: bool, caption: str):
        """
        Initialize the map cursor.

        Arguments
        - x: The x coordinate, from -128 to 127.
        - y: The y coordinate, from -128 to 127.
        - direction: The facing of the cursor, from 0 to 15.
        - type: The type (color/style) of the map cursor.
        - visible: Whether the cursor is visible by default.
        - caption: cursor caption
        """
        ...


    def getX(self) -> int:
        """
        Get the X position of this cursor.

        Returns
        - The X coordinate.
        """
        ...


    def getY(self) -> int:
        """
        Get the Y position of this cursor.

        Returns
        - The Y coordinate.
        """
        ...


    def getDirection(self) -> int:
        """
        Get the direction of this cursor.

        Returns
        - The facing of the cursor, from 0 to 15.
        """
        ...


    def getType(self) -> "Type":
        """
        Get the type of this cursor.

        Returns
        - The type (color/style) of the map cursor.
        """
        ...


    def getRawType(self) -> int:
        """
        Get the type of this cursor.

        Returns
        - The type (color/style) of the map cursor.

        Deprecated
        - Magic value
        """
        ...


    def isVisible(self) -> bool:
        """
        Get the visibility status of this cursor.

        Returns
        - True if visible, False otherwise.
        """
        ...


    def setX(self, x: int) -> None:
        """
        Set the X position of this cursor.

        Arguments
        - x: The X coordinate.
        """
        ...


    def setY(self, y: int) -> None:
        """
        Set the Y position of this cursor.

        Arguments
        - y: The Y coordinate.
        """
        ...


    def setDirection(self, direction: int) -> None:
        """
        Set the direction of this cursor.

        Arguments
        - direction: The facing of the cursor, from 0 to 15.
        """
        ...


    def setType(self, type: "Type") -> None:
        """
        Set the type of this cursor.

        Arguments
        - type: The type (color/style) of the map cursor.
        """
        ...


    def setRawType(self, type: int) -> None:
        """
        Set the type of this cursor.

        Arguments
        - type: The type (color/style) of the map cursor.

        Deprecated
        - Magic value
        """
        ...


    def setVisible(self, visible: bool) -> None:
        """
        Set the visibility status of this cursor.

        Arguments
        - visible: True if visible.
        """
        ...


    def getCaption(self) -> str:
        """
        Gets the caption on this cursor.

        Returns
        - caption
        """
        ...


    def setCaption(self, caption: str) -> None:
        """
        Sets the caption on this cursor.

        Arguments
        - caption: new caption
        """
        ...


    class Type(Enum):
        """
        Represents the standard types of map cursors. More may be made
        available by resource packs - the value is used by the client as an
        index in the file './assets/minecraft/textures/map/map_icons.png' from minecraft.jar or from a
        resource pack.
        """

        WHITE_POINTER = (0)
        GREEN_POINTER = (1)
        RED_POINTER = (2)
        BLUE_POINTER = (3)
        WHITE_CROSS = (4)
        RED_MARKER = (5)
        WHITE_CIRCLE = (6)
        SMALL_WHITE_CIRCLE = (7)
        MANSION = (8)
        TEMPLE = (9)
        BANNER_WHITE = (10)
        BANNER_ORANGE = (11)
        BANNER_MAGENTA = (12)
        BANNER_LIGHT_BLUE = (13)
        BANNER_YELLOW = (14)
        BANNER_LIME = (15)
        BANNER_PINK = (16)
        BANNER_GRAY = (17)
        BANNER_LIGHT_GRAY = (18)
        BANNER_CYAN = (19)
        BANNER_PURPLE = (20)
        BANNER_BLUE = (21)
        BANNER_BROWN = (22)
        BANNER_GREEN = (23)
        BANNER_RED = (24)
        BANNER_BLACK = (25)
        RED_X = (26)
        DESERT_VILLAGE = (27)
        PLAINS_VILLAGE = (28)
        SAVANNA_VILLAGE = (29)
        SNOWY_VILLAGE = (30)
        TAIGA_VILLAGE = (31)
        JUNGLE_TEMPLE = (32)
        SWAMP_HUT = (33)


        def getValue(self) -> int:
            """
            Gets the internal value of the cursor.

            Returns
            - the value

            Deprecated
            - Magic value
            """
            ...


        @staticmethod
        def byValue(value: int) -> "Type":
            """
            Get a cursor by its internal value.

            Arguments
            - value: the value

            Returns
            - the matching type

            Deprecated
            - Magic value
            """
            ...



"""
Python module generated from Java source file org.bukkit.command.BlockCommandSender

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.command import *
from typing import Any, Callable, Iterable, Tuple


class BlockCommandSender(CommandSender):

    def getBlock(self) -> "Block":
        """
        Returns the block this command sender belongs to

        Returns
        - Block for the command sender
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.BatToggleSleepEvent

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Bat
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class BatToggleSleepEvent(EntityEvent, Cancellable):
    """
    Called when a bat attempts to sleep or wake up from its slumber.
    
    If a Bat Toggle Sleep event is cancelled, the Bat will not toggle its sleep
    state.
    """

    def __init__(self, what: "Bat", awake: bool):
        ...


    def isAwake(self) -> bool:
        """
        Get whether or not the bat is attempting to awaken.

        Returns
        - True if trying to awaken, False otherwise
        """
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def isCancelled(self) -> bool:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.entity.Frog

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.util import Locale
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Frog(Animals):
    """
    A Frog.
    """

    def getTongueTarget(self) -> "Entity":
        """
        Gets the tongue target of this frog.

        Returns
        - tongue target or null if not set
        """
        ...


    def setTongueTarget(self, target: "Entity") -> None:
        """
        Sets the tongue target of this frog.

        Arguments
        - target: tongue target or null to clear
        """
        ...


    def getVariant(self) -> "Variant":
        """
        Get the variant of this frog.

        Returns
        - frog variant
        """
        ...


    def setVariant(self, variant: "Variant") -> None:
        """
        Set the variant of this frog.

        Arguments
        - variant: frog variant
        """
        ...


    class Variant(Enum):
        """
        Represents the variant of a frog - ie its color.
        """

        TEMPERATE = 0
        """
        Temperate (brown-orange) frog.
        """
        WARM = 1
        """
        Warm (gray) frog.
        """
        COLD = 2
        """
        Cold (green) frog.
        """


        def getKey(self) -> "NamespacedKey":
            ...



from .Criterias import Criterias
from .Criteria import Criteria
from .Scoreboard import Scoreboard
from .Team import Team
from .DisplaySlot import DisplaySlot
from .RenderType import RenderType
from .Score import Score
from .NameTagVisibility import NameTagVisibility
from .Objective import Objective
from .ScoreboardManager import ScoreboardManager


"""
Python module generated from Java source file org.bukkit.boss.KeyedBossBar

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Keyed
from org.bukkit.boss import *
from typing import Any, Callable, Iterable, Tuple


class KeyedBossBar(BossBar, Keyed):
    """
    Represents a custom BossBar that has a
    org.bukkit.NamespacedKey
    """





"""
Python module generated from Java source file org.bukkit.event.entity.EntityCreatePortalEvent

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import PortalType
from org.bukkit.block import BlockState
from org.bukkit.entity import LivingEntity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from org.bukkit.event.world import PortalCreateEvent
from typing import Any, Callable, Iterable, Tuple


class EntityCreatePortalEvent(EntityEvent, Cancellable):
    """
    Thrown when a Living Entity creates a portal in a world.

    Deprecated
    - Use PortalCreateEvent
    """

    def __init__(self, what: "LivingEntity", blocks: list["BlockState"], type: "PortalType"):
        ...


    def getEntity(self) -> "LivingEntity":
        ...


    def getBlocks(self) -> list["BlockState"]:
        """
        Gets a list of all blocks associated with the portal.

        Returns
        - List of blocks that will be changed.
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getPortalType(self) -> "PortalType":
        """
        Gets the type of portal that is trying to be created.

        Returns
        - Type of portal.
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.ItemMeta

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import Multimap
from org.bukkit.attribute import Attribute
from org.bukkit.attribute import AttributeModifier
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.enchantments import Enchantment
from org.bukkit.inventory import EquipmentSlot
from org.bukkit.inventory import ItemFlag
from org.bukkit.inventory.meta import *
from org.bukkit.inventory.meta.tags import CustomItemTagContainer
from org.bukkit.persistence import PersistentDataHolder
from typing import Any, Callable, Iterable, Tuple


class ItemMeta(Cloneable, ConfigurationSerializable, PersistentDataHolder):
    """
    This type represents the storage mechanism for auxiliary item data.
    
    An implementation will handle the creation and application for ItemMeta.
    This class should not be implemented by a plugin in a live environment.
    """

    def hasDisplayName(self) -> bool:
        """
        Checks for existence of a display name.

        Returns
        - True if this has a display name
        """
        ...


    def getDisplayName(self) -> str:
        """
        Gets the display name that is set.
        
        Plugins should check that hasDisplayName() returns `True`
        before calling this method.

        Returns
        - the display name that is set
        """
        ...


    def setDisplayName(self, name: str) -> None:
        """
        Sets the display name.

        Arguments
        - name: the name to set
        """
        ...


    def hasLocalizedName(self) -> bool:
        """
        Checks for existence of a localized name.

        Returns
        - True if this has a localized name
        """
        ...


    def getLocalizedName(self) -> str:
        """
        Gets the localized display name that is set.
        
        Plugins should check that hasLocalizedName() returns `True`
        before calling this method.

        Returns
        - the localized name that is set
        """
        ...


    def setLocalizedName(self, name: str) -> None:
        """
        Sets the localized name.

        Arguments
        - name: the name to set
        """
        ...


    def hasLore(self) -> bool:
        """
        Checks for existence of lore.

        Returns
        - True if this has lore
        """
        ...


    def getLore(self) -> list[str]:
        """
        Gets the lore that is set.
        
        Plugins should check if hasLore() returns `True` before
        calling this method.

        Returns
        - a list of lore that is set
        """
        ...


    def setLore(self, lore: list[str]) -> None:
        """
        Sets the lore for this item.
        Removes lore when given null.

        Arguments
        - lore: the lore that will be set
        """
        ...


    def hasCustomModelData(self) -> bool:
        """
        Checks for existence of custom model data.
        
        CustomModelData is an integer that may be associated client side with a
        custom item model.

        Returns
        - True if this has custom model data
        """
        ...


    def getCustomModelData(self) -> int:
        """
        Gets the custom model data that is set.
        
        CustomModelData is an integer that may be associated client side with a
        custom item model.
        
        Plugins should check that hasCustomModelData() returns `True`
        before calling this method.

        Returns
        - the custom model data that is set
        """
        ...


    def setCustomModelData(self, data: "Integer") -> None:
        """
        Sets the custom model data.
        
        CustomModelData is an integer that may be associated client side with a
        custom item model.

        Arguments
        - data: the data to set, or null to clear
        """
        ...


    def hasEnchants(self) -> bool:
        """
        Checks for the existence of any enchantments.

        Returns
        - True if an enchantment exists on this meta
        """
        ...


    def hasEnchant(self, ench: "Enchantment") -> bool:
        """
        Checks for existence of the specified enchantment.

        Arguments
        - ench: enchantment to check

        Returns
        - True if this enchantment exists for this meta
        """
        ...


    def getEnchantLevel(self, ench: "Enchantment") -> int:
        """
        Checks for the level of the specified enchantment.

        Arguments
        - ench: enchantment to check

        Returns
        - The level that the specified enchantment has, or 0 if none
        """
        ...


    def getEnchants(self) -> dict["Enchantment", "Integer"]:
        """
        Returns a copy the enchantments in this ItemMeta. 
        Returns an empty map if none.

        Returns
        - An immutable copy of the enchantments
        """
        ...


    def addEnchant(self, ench: "Enchantment", level: int, ignoreLevelRestriction: bool) -> bool:
        """
        Adds the specified enchantment to this item meta.

        Arguments
        - ench: Enchantment to add
        - level: Level for the enchantment
        - ignoreLevelRestriction: this indicates the enchantment should be
            applied, ignoring the level limit

        Returns
        - True if the item meta changed as a result of this call, False
            otherwise
        """
        ...


    def removeEnchant(self, ench: "Enchantment") -> bool:
        """
        Removes the specified enchantment from this item meta.

        Arguments
        - ench: Enchantment to remove

        Returns
        - True if the item meta changed as a result of this call, False
            otherwise
        """
        ...


    def removeEnchantments(self) -> None:
        """
        Removes all enchantments from this item meta.
        """
        ...


    def hasConflictingEnchant(self, ench: "Enchantment") -> bool:
        """
        Checks if the specified enchantment conflicts with any enchantments in
        this ItemMeta.

        Arguments
        - ench: enchantment to test

        Returns
        - True if the enchantment conflicts, False otherwise
        """
        ...


    def addItemFlags(self, *itemFlags: Tuple["ItemFlag", ...]) -> None:
        """
        Set itemflags which should be ignored when rendering a ItemStack in the Client. This Method does silently ignore double set itemFlags.

        Arguments
        - itemFlags: The hideflags which shouldn't be rendered
        """
        ...


    def removeItemFlags(self, *itemFlags: Tuple["ItemFlag", ...]) -> None:
        """
        Remove specific set of itemFlags. This tells the Client it should render it again. This Method does silently ignore double removed itemFlags.

        Arguments
        - itemFlags: Hideflags which should be removed
        """
        ...


    def getItemFlags(self) -> set["ItemFlag"]:
        """
        Get current set itemFlags. The collection returned is unmodifiable.

        Returns
        - A set of all itemFlags set
        """
        ...


    def hasItemFlag(self, flag: "ItemFlag") -> bool:
        """
        Check if the specified flag is present on this item.

        Arguments
        - flag: the flag to check

        Returns
        - if it is present
        """
        ...


    def isUnbreakable(self) -> bool:
        """
        Return if the unbreakable tag is True. An unbreakable item will not lose
        durability.

        Returns
        - True if the unbreakable tag is True
        """
        ...


    def setUnbreakable(self, unbreakable: bool) -> None:
        """
        Sets the unbreakable tag. An unbreakable item will not lose durability.

        Arguments
        - unbreakable: True if set unbreakable
        """
        ...


    def hasAttributeModifiers(self) -> bool:
        """
        Checks for the existence of any AttributeModifiers.

        Returns
        - True if any AttributeModifiers exist
        """
        ...


    def getAttributeModifiers(self) -> "Multimap"["Attribute", "AttributeModifier"]:
        """
        Return an immutable copy of all Attributes and
        their modifiers in this ItemMeta.
        Returns null if none exist.

        Returns
        - an immutable Multimap of Attributes
                and their AttributeModifiers, or null if none exist
        """
        ...


    def getAttributeModifiers(self, slot: "EquipmentSlot") -> "Multimap"["Attribute", "AttributeModifier"]:
        """
        Return an immutable copy of all Attributes and their
        AttributeModifiers for a given EquipmentSlot.
        Any AttributeModifier that does have have a given
        EquipmentSlot will be returned. This is because
        AttributeModifiers without a slot are active in any slot.
        If there are no attributes set for the given slot, an empty map
        will be returned.

        Arguments
        - slot: the EquipmentSlot to check

        Returns
        - the immutable Multimap with the
                respective Attributes and modifiers, or an empty map
                if no attributes are set.
        """
        ...


    def getAttributeModifiers(self, attribute: "Attribute") -> Iterable["AttributeModifier"]:
        """
        Return an immutable copy of all AttributeModifiers
        for a given Attribute

        Arguments
        - attribute: the Attribute

        Returns
        - an immutable collection of AttributeModifiers
                 or null if no AttributeModifiers exist for the Attribute.

        Raises
        - NullPointerException: if Attribute is null
        """
        ...


    def addAttributeModifier(self, attribute: "Attribute", modifier: "AttributeModifier") -> bool:
        """
        Add an Attribute and it's Modifier.
        AttributeModifiers can now support EquipmentSlots.
        If not set, the AttributeModifier will be active in ALL slots.
        
        Two AttributeModifiers that have the same java.util.UUID
        cannot exist on the same Attribute.

        Arguments
        - attribute: the Attribute to modify
        - modifier: the AttributeModifier specifying the modification

        Returns
        - True if the Attribute and AttributeModifier were
                successfully added

        Raises
        - NullPointerException: if Attribute is null
        - NullPointerException: if AttributeModifier is null
        - IllegalArgumentException: if AttributeModifier already exists
        """
        ...


    def setAttributeModifiers(self, attributeModifiers: "Multimap"["Attribute", "AttributeModifier"]) -> None:
        """
        Set all Attributes and their AttributeModifiers.
        To clear all currently set Attributes and AttributeModifiers use
        null or an empty Multimap.
        If not null nor empty, this will filter all entries that are not-null
        and add them to the ItemStack.

        Arguments
        - attributeModifiers: the new Multimap containing the Attributes
                                  and their AttributeModifiers
        """
        ...


    def removeAttributeModifier(self, attribute: "Attribute") -> bool:
        """
        Remove all AttributeModifiers associated with the given
        Attribute.
        This will return False if nothing was removed.

        Arguments
        - attribute: attribute to remove

        Returns
        - True if all modifiers were removed from a given
                         Attribute. Returns False if no attributes were
                         removed.

        Raises
        - NullPointerException: if Attribute is null
        """
        ...


    def removeAttributeModifier(self, slot: "EquipmentSlot") -> bool:
        """
        Remove all Attributes and AttributeModifiers for a
        given EquipmentSlot.
        If the given EquipmentSlot is null, this will remove all
        AttributeModifiers that do not have an EquipmentSlot set.

        Arguments
        - slot: the EquipmentSlot to clear all Attributes and
                    their modifiers for

        Returns
        - True if all modifiers were removed that match the given
                EquipmentSlot.
        """
        ...


    def removeAttributeModifier(self, attribute: "Attribute", modifier: "AttributeModifier") -> bool:
        """
        Remove a specific Attribute and AttributeModifier.
        AttributeModifiers are matched according to their java.util.UUID.

        Arguments
        - attribute: the Attribute to remove
        - modifier: the AttributeModifier to remove

        Returns
        - if any attribute modifiers were remove

        Raises
        - NullPointerException: if the Attribute is null
        - NullPointerException: if the AttributeModifier is null

        See
        - AttributeModifier.getUniqueId()
        """
        ...


    def getAsString(self) -> str:
        """
        Get this ItemMeta as an NBT string.
        
        This string should not be relied upon as a serializable value. If
        serialization is desired, the ConfigurationSerializable API
        should be used instead.

        Returns
        - the NBT string
        """
        ...


    def getCustomTagContainer(self) -> "CustomItemTagContainer":
        """
        Returns a public custom tag container capable of storing tags on the
        item.
        
        Those tags will be sent to the client with all of their content, so the
        client is capable of reading them. This will result in the player seeing
        a NBT Tag notification on the item.
        
        These tags can also be modified by the client once in creative mode

        Returns
        - the custom tag container

        Deprecated
        - this API part has been replaced by the PersistentDataHolder API.
        Please use PersistentDataHolder.getPersistentDataContainer() instead of this.
        """
        ...


    def setVersion(self, version: int) -> None:
        """
        Internal use only! Do not use under any circumstances!

        Arguments
        - version: version

        Unknown Tags
        - internal use only
        """
        ...


    def clone(self) -> "ItemMeta":
        ...



"""
Python module generated from Java source file org.bukkit.event.world.ChunkPopulateEvent

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Chunk
from org.bukkit.event import HandlerList
from org.bukkit.event.world import *
from org.bukkit.generator import BlockPopulator
from typing import Any, Callable, Iterable, Tuple


class ChunkPopulateEvent(ChunkEvent):
    """
    Thrown when a newly generated chunk has finished being populated.
    
    **Note:** Do not use this to generated blocks in a newly generated chunk.
    Use a BlockPopulator instead.
    """

    def __init__(self, chunk: "Chunk"):
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



from .Type import Type
from .Field import Field
from .AccessibleObject import AccessibleObject
from .Constructor import Constructor
from .InvocationTargetException import InvocationTargetException
from .Modifier import Modifier
from .ParameterizedType import ParameterizedType
from .Array import Array
from .GenericArrayType import GenericArrayType
from .GenericDeclaration import GenericDeclaration
from .TypeVariable import TypeVariable
from .WildcardType import WildcardType
from .Method import Method
from .Member import Member
from .InvocationHandler import InvocationHandler
from .Proxy import Proxy
from .AnnotatedElement import AnnotatedElement
from .AnnotatedType import AnnotatedType


"""
Python module generated from Java source file com.google.gson.internal.bind.DefaultDateTypeAdapter

Java source file obtained from artifact gson version 2.10.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import JsonSyntaxException
from com.google.gson import TypeAdapter
from com.google.gson import TypeAdapterFactory
from com.google.gson.internal import JavaVersion
from com.google.gson.internal import PreJava9DateFormatProvider
from com.google.gson.internal.bind import *
from com.google.gson.internal.bind.util import ISO8601Utils
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonToken
from com.google.gson.stream import JsonWriter
from java.io import IOException
from java.text import DateFormat
from java.text import ParseException
from java.text import ParsePosition
from java.text import SimpleDateFormat
from java.util import Date
from java.util import Locale
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class DefaultDateTypeAdapter(TypeAdapter):
    """
    This type adapter supports subclasses of date by defining a
    DefaultDateTypeAdapter.DateType and then using its `createAdapterFactory`
    methods.

    Author(s)
    - Joel Leitch
    """

    def write(self, out: "JsonWriter", value: "Date") -> None:
        ...


    def read(self, in: "JsonReader") -> "T":
        ...


    def toString(self) -> str:
        ...


    class DateType:

        DATE = DateType<Date>(Date.class) {
        
            @Override
            protected Date deserialize(Date date) {
                return date;
            }
        }


        def createAdapterFactory(self, datePattern: str) -> "TypeAdapterFactory":
            ...


        def createAdapterFactory(self, style: int) -> "TypeAdapterFactory":
            ...


        def createAdapterFactory(self, dateStyle: int, timeStyle: int) -> "TypeAdapterFactory":
            ...


        def createDefaultsAdapterFactory(self) -> "TypeAdapterFactory":
            ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.trim.TrimMaterial

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Keyed
from org.bukkit import Material
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit import Translatable
from org.bukkit.inventory.meta.trim import *
from typing import Any, Callable, Iterable, Tuple


class TrimMaterial(Keyed, Translatable):
    """
    Represents a material that may be used in an ArmorTrim.
    """

    QUARTZ = Registry.TRIM_MATERIAL.get(NamespacedKey.minecraft("quartz"))
    """
    Material.QUARTZ.
    """
    IRON = Registry.TRIM_MATERIAL.get(NamespacedKey.minecraft("iron"))
    """
    Material.IRON_INGOT.
    """
    NETHERITE = Registry.TRIM_MATERIAL.get(NamespacedKey.minecraft("netherite"))
    """
    Material.NETHERITE_INGOT.
    """
    REDSTONE = Registry.TRIM_MATERIAL.get(NamespacedKey.minecraft("redstone"))
    """
    Material.REDSTONE.
    """
    COPPER = Registry.TRIM_MATERIAL.get(NamespacedKey.minecraft("copper"))
    """
    Material.COPPER_INGOT.
    """
    GOLD = Registry.TRIM_MATERIAL.get(NamespacedKey.minecraft("gold"))
    """
    Material.GOLD_INGOT.
    """
    EMERALD = Registry.TRIM_MATERIAL.get(NamespacedKey.minecraft("emerald"))
    """
    Material.EMERALD.
    """
    DIAMOND = Registry.TRIM_MATERIAL.get(NamespacedKey.minecraft("diamond"))
    """
    Material.DIAMOND.
    """
    LAPIS = Registry.TRIM_MATERIAL.get(NamespacedKey.minecraft("lapis"))
    """
    Material.LAPIS_LAZULI.
    """
    AMETHYST = Registry.TRIM_MATERIAL.get(NamespacedKey.minecraft("amethyst"))
    """
    Material.AMETHYST_SHARD.
    """



"""
Python module generated from Java source file org.bukkit.entity.EnderDragonPart

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class EnderDragonPart(ComplexEntityPart, Damageable):
    """
    Represents an ender dragon part
    """

    def getParent(self) -> "EnderDragon":
        ...



from .PotionEffectTypeWrapper import PotionEffectTypeWrapper
from .PotionType import PotionType
from .PotionData import PotionData
from .PotionBrewer import PotionBrewer
from .Potion import Potion
from .PotionEffectType import PotionEffectType
from .PotionEffect import PotionEffect


from .Damageable import Damageable
from .BookMeta import BookMeta
from .SkullMeta import SkullMeta
from .Repairable import Repairable
from .TropicalFishBucketMeta import TropicalFishBucketMeta
from .SpawnEggMeta import SpawnEggMeta
from .FireworkEffectMeta import FireworkEffectMeta
from .BlockDataMeta import BlockDataMeta
from .BlockStateMeta import BlockStateMeta
from .ItemMeta import ItemMeta
from .ArmorMeta import ArmorMeta
from .PotionMeta import PotionMeta
from .CrossbowMeta import CrossbowMeta
from .BundleMeta import BundleMeta
from .AxolotlBucketMeta import AxolotlBucketMeta
from .ColorableArmorMeta import ColorableArmorMeta
from .KnowledgeBookMeta import KnowledgeBookMeta
from .MapMeta import MapMeta
from .SuspiciousStewMeta import SuspiciousStewMeta
from .MusicInstrumentMeta import MusicInstrumentMeta
from .FireworkMeta import FireworkMeta
from .CompassMeta import CompassMeta
from .BannerMeta import BannerMeta
from .EnchantmentStorageMeta import EnchantmentStorageMeta
from .LeatherArmorMeta import LeatherArmorMeta


"""
Python module generated from Java source file org.bukkit.event.block.BlockBurnEvent

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class BlockBurnEvent(BlockEvent, Cancellable):
    """
    Called when a block is destroyed as a result of being burnt by fire.
    
    If a Block Burn event is cancelled, the block will not be destroyed as a
    result of being burnt by fire.
    """

    def __init__(self, block: "Block"):
        ...


    def __init__(self, block: "Block", ignitingBlock: "Block"):
        ...


    def getIgnitingBlock(self) -> "Block":
        """
        Gets the block which ignited this block.

        Returns
        - The Block that ignited and burned this block, or null if no
        source block exists
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



from .InactivityConversationCanceller import InactivityConversationCanceller
from .ValidatingPrompt import ValidatingPrompt
from .PlayerNamePrompt import PlayerNamePrompt
from .ConversationPrefix import ConversationPrefix
from .RegexPrompt import RegexPrompt
from .ConversationContext import ConversationContext
from .Conversation import Conversation
from .BooleanPrompt import BooleanPrompt
from .StringPrompt import StringPrompt
from .MessagePrompt import MessagePrompt
from .NullConversationPrefix import NullConversationPrefix
from .ConversationCanceller import ConversationCanceller
from .ExactMatchConversationCanceller import ExactMatchConversationCanceller
from .ManuallyAbandonedConversationCanceller import ManuallyAbandonedConversationCanceller
from .ConversationAbandonedEvent import ConversationAbandonedEvent
from .Prompt import Prompt
from .ConversationFactory import ConversationFactory
from .FixedSetPrompt import FixedSetPrompt
from .ConversationAbandonedListener import ConversationAbandonedListener
from .NumericPrompt import NumericPrompt
from .PluginNameConversationPrefix import PluginNameConversationPrefix
from .Conversable import Conversable


"""
Python module generated from Java source file org.bukkit.event.vehicle.VehicleEntityCollisionEvent

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Entity
from org.bukkit.entity import Vehicle
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.vehicle import *
from typing import Any, Callable, Iterable, Tuple


class VehicleEntityCollisionEvent(VehicleCollisionEvent, Cancellable):
    """
    Raised when a vehicle collides with an entity.
    """

    def __init__(self, vehicle: "Vehicle", entity: "Entity"):
        ...


    def getEntity(self) -> "Entity":
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def isPickupCancelled(self) -> bool:
        ...


    def setPickupCancelled(self, cancel: bool) -> None:
        ...


    def isCollisionCancelled(self) -> bool:
        ...


    def setCollisionCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableSortedMapFauxverideShim

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import DoNotCall
from java.util.function import BinaryOperator
from java.util.function import Function
from java.util.stream import Collector
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmutableSortedMapFauxverideShim(ImmutableMap):
    """
    "Overrides" the ImmutableMap static methods that lack ImmutableSortedMap
    equivalents with deprecated, exception-throwing versions. See ImmutableSortedSetFauxverideShim for details.

    Author(s)
    - Chris Povirk
    """

    @staticmethod
    def toImmutableMap(keyFunction: "Function"["T", "K"], valueFunction: "Function"["T", "V"]) -> "Collector"["T", Any, "ImmutableMap"["K", "V"]]:
        """
        Not supported. Use ImmutableSortedMap.toImmutableSortedMap, which offers better
        type-safety, instead. This method exists only to hide ImmutableMap.toImmutableMap from
        consumers of `ImmutableSortedMap`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Use ImmutableSortedMap.toImmutableSortedMap.
        """
        ...


    @staticmethod
    def toImmutableMap(keyFunction: "Function"["T", "K"], valueFunction: "Function"["T", "V"], mergeFunction: "BinaryOperator"["V"]) -> "Collector"["T", Any, "ImmutableMap"["K", "V"]]:
        """
        Not supported. Use ImmutableSortedMap.toImmutableSortedMap, which offers better
        type-safety, instead. This method exists only to hide ImmutableMap.toImmutableMap from
        consumers of `ImmutableSortedMap`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Use ImmutableSortedMap.toImmutableSortedMap.
        """
        ...


    @staticmethod
    def builder() -> "ImmutableSortedMap.Builder"["K", "V"]:
        """
        Not supported. Use ImmutableSortedMap.naturalOrder, which offers better type-safety,
        instead. This method exists only to hide ImmutableMap.builder from consumers of `ImmutableSortedMap`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Use ImmutableSortedMap.naturalOrder, which offers better type-safety.
        """
        ...


    @staticmethod
    def builderWithExpectedSize(expectedSize: int) -> "ImmutableSortedMap.Builder"["K", "V"]:
        """
        Not supported for ImmutableSortedMap.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Not supported for ImmutableSortedMap.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain a non-`Comparable`
        key.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this dummy
        version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass a key of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls to will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V", k8: "K", v8: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V", k8: "K", v8: "V", k9: "K", v9: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V", k8: "K", v8: "V", k9: "K", v9: "V", k10: "K", v10: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def ofEntries(*entries: Tuple["Entry"["K", "V"], ...]) -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. Use `ImmutableSortedMap.copyOf(ImmutableMap.ofEntries(...))`.

        Deprecated
        - Use `ImmutableSortedMap.copyOf(ImmutableMap.ofEntries(...))`.
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.DaylightDetector

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import AnaloguePowerable
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class DaylightDetector(AnaloguePowerable):
    """
    'inverted' denotes whether this daylight detector is in the inverted mode,
    i.e. activates in the absence of light rather than presence."
    """

    def isInverted(self) -> bool:
        """
        Gets the value of the 'inverted' property.

        Returns
        - the 'inverted' value
        """
        ...


    def setInverted(self, inverted: bool) -> None:
        """
        Sets the value of the 'inverted' property.

        Arguments
        - inverted: the new 'inverted' value
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerStatisticIncrementEvent

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit import Statistic
from org.bukkit.entity import EntityType
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerStatisticIncrementEvent(PlayerEvent, Cancellable):
    """
    Called when a player statistic is incremented.
    
    This event is not called for some high frequency statistics, e.g. movement
    based statistics.
    """

    def __init__(self, player: "Player", statistic: "Statistic", initialValue: int, newValue: int):
        ...


    def __init__(self, player: "Player", statistic: "Statistic", initialValue: int, newValue: int, entityType: "EntityType"):
        ...


    def __init__(self, player: "Player", statistic: "Statistic", initialValue: int, newValue: int, material: "Material"):
        ...


    def getStatistic(self) -> "Statistic":
        """
        Gets the statistic that is being incremented.

        Returns
        - the incremented statistic
        """
        ...


    def getPreviousValue(self) -> int:
        """
        Gets the previous value of the statistic.

        Returns
        - the previous value of the statistic
        """
        ...


    def getNewValue(self) -> int:
        """
        Gets the new value of the statistic.

        Returns
        - the new value of the statistic
        """
        ...


    def getEntityType(self) -> "EntityType":
        """
        Gets the EntityType if .getStatistic() getStatistic() is an
        entity statistic otherwise returns null.

        Returns
        - the EntityType of the statistic
        """
        ...


    def getMaterial(self) -> "Material":
        """
        Gets the Material if .getStatistic() getStatistic() is a block
        or item statistic otherwise returns null.

        Returns
        - the Material of the statistic
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



from .Tripwire import Tripwire
from .DetectorRail import DetectorRail
from .TexturedMaterial import TexturedMaterial
from .SpawnEgg import SpawnEgg
from .ExtendedRails import ExtendedRails
from .Banner import Banner
from .PoweredRail import PoweredRail
from .PistonBaseMaterial import PistonBaseMaterial
from .Skull import Skull
from .Torch import Torch
from .TripwireHook import TripwireHook
from .Vine import Vine
from .Colorable import Colorable
from .Attachable import Attachable
from .Lever import Lever
from .Sapling import Sapling
from .Mushroom import Mushroom
from .FurnaceAndDispenser import FurnaceAndDispenser
from .Command import Command
from .Sandstone import Sandstone
from .NetherWarts import NetherWarts
from .Chest import Chest
from .SmoothBrick import SmoothBrick
from .Redstone import Redstone
from .EnderChest import EnderChest
from .Tree import Tree
from .LongGrass import LongGrass
from .PressureSensor import PressureSensor
from .Observer import Observer
from .RedstoneWire import RedstoneWire
from .Comparator import Comparator
from .Rails import Rails
from .Hopper import Hopper
from .PistonExtensionMaterial import PistonExtensionMaterial
from .Pumpkin import Pumpkin
from .Dispenser import Dispenser
from .Stairs import Stairs
from .Cauldron import Cauldron
from .WoodenStep import WoodenStep
from .FlowerPot import FlowerPot
from .RedstoneTorch import RedstoneTorch
from .Bed import Bed
from .Sign import Sign
from .SimpleAttachableMaterialData import SimpleAttachableMaterialData
from .PressurePlate import PressurePlate
from .Gate import Gate
from .Directional import Directional
from .Cake import Cake
from .Diode import Diode
from .Leaves import Leaves
from .Wool import Wool
from .CocoaPlant import CocoaPlant
from .Furnace import Furnace
from .Crops import Crops
from .Step import Step
from .DirectionalContainer import DirectionalContainer
from .Openable import Openable
from .TrapDoor import TrapDoor
from .MaterialData import MaterialData
from .Dye import Dye
from .Coal import Coal
from .Ladder import Ladder
from .MonsterEggs import MonsterEggs
from .Door import Door
from .Button import Button
from .Wood import Wood


"""
Python module generated from Java source file org.bukkit.loot.LootContext

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from org.bukkit import Location
from org.bukkit.entity import Entity
from org.bukkit.entity import HumanEntity
from org.bukkit.loot import *
from typing import Any, Callable, Iterable, Tuple


class LootContext:
    """
    Represents additional information a LootTable can use to modify it's
    generated loot.
    """

    DEFAULT_LOOT_MODIFIER = -1


    def getLocation(self) -> "Location":
        """
        The Location to store where the loot will be generated.

        Returns
        - the Location of where the loot will be generated
        """
        ...


    def getLuck(self) -> float:
        """
        Represents the org.bukkit.potion.PotionEffectType.LUCK that an
        entity can have. The higher the value the better chance of receiving more
        loot.

        Returns
        - luck
        """
        ...


    def getLootingModifier(self) -> int:
        """
        Represents the
        org.bukkit.enchantments.Enchantment.LOOT_BONUS_MOBS the
        .getKiller() entity has on their equipped item.
        
        This value is only set via
        LootContext.Builder.lootingModifier(int). If not set, the
        .getKiller() entity's looting level will be used instead.

        Returns
        - the looting level
        """
        ...


    def getLootedEntity(self) -> "Entity":
        """
        Get the Entity that was killed. Can be null.

        Returns
        - the looted entity or null
        """
        ...


    def getKiller(self) -> "HumanEntity":
        """
        Get the HumanEntity who killed the .getLootedEntity().
        Can be null.

        Returns
        - the killer entity, or null.
        """
        ...


    class Builder:
        """
        Utility class to make building LootContext easier. The only
        required argument is Location with a valid (non-null)
        org.bukkit.World.
        """

        def __init__(self, location: "Location"):
            """
            Creates a new LootContext.Builder instance to facilitate easy
            creation of LootContexts.

            Arguments
            - location: the location the LootContext should use
            """
            ...


        def luck(self, luck: float) -> "Builder":
            """
            Set how much luck to have when generating loot.

            Arguments
            - luck: the luck level

            Returns
            - the Builder
            """
            ...


        def lootingModifier(self, modifier: int) -> "Builder":
            """
            Set the org.bukkit.enchantments.Enchantment.LOOT_BONUS_MOBS
            level equivalent to use when generating loot. Values less than or
            equal to 0 will force the LootTable to only return a single
            org.bukkit.inventory.ItemStack per pool.

            Arguments
            - modifier: the looting level modifier

            Returns
            - the Builder
            """
            ...


        def lootedEntity(self, lootedEntity: "Entity") -> "Builder":
            """
            The entity that was killed.

            Arguments
            - lootedEntity: the looted entity

            Returns
            - the Builder
            """
            ...


        def killer(self, killer: "HumanEntity") -> "Builder":
            """
            Set the org.bukkit.entity.HumanEntity that killed
            .getLootedEntity(). This entity will be used to get the
            looting level if .lootingModifier(int) is not set.

            Arguments
            - killer: the killer entity

            Returns
            - the Builder
            """
            ...


        def build(self) -> "LootContext":
            """
            Create a new LootContext instance using the supplied
            parameters.

            Returns
            - a new LootContext instance
            """
            ...



"""
Python module generated from Java source file com.google.gson.annotations.Expose

Java source file obtained from artifact gson version 2.10.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.annotations import *
from typing import Any, Callable, Iterable, Tuple


class Expose:
    """
    An annotation that indicates this member should be exposed for JSON
    serialization or deserialization.
    
    This annotation has no effect unless you build com.google.gson.Gson
    with a com.google.gson.GsonBuilder and invoke
    com.google.gson.GsonBuilder.excludeFieldsWithoutExposeAnnotation()
    method.
    
    Here is an example of how this annotation is meant to be used:
    ```
    public class User {
      &#64;Expose private String firstName;
      &#64;Expose(serialize = False) private String lastName;
      &#64;Expose (serialize = False, deserialize = False) private String emailAddress;
      private String password;
    }
    ```
    If you created Gson with `new Gson()`, the `toJson()` and `fromJson()`
    methods will use the `password` field along-with `firstName`, `lastName`,
    and `emailAddress` for serialization and deserialization. However, if you created Gson
    with `Gson gson = new GsonBuilder().excludeFieldsWithoutExposeAnnotation().create()`
    then the `toJson()` and `fromJson()` methods of Gson will exclude the
    `password` field. This is because the `password` field is not marked with the
    `@Expose` annotation. Gson will also exclude `lastName` and `emailAddress`
    from serialization since `serialize` is set to `False`. Similarly, Gson will
    exclude `emailAddress` from deserialization since `deserialize` is set to False.
    
    Note that another way to achieve the same effect would have been to just mark the
    `password` field as `transient`, and Gson would have excluded it even with default
    settings. The `@Expose` annotation is useful in a style of programming where you want to
    explicitly specify all fields that should get considered for serialization or deserialization.

    Author(s)
    - Joel Leitch
    """

    def serialize(self) -> bool:
        """
        If `True`, the field marked with this annotation is written out in the JSON while
        serializing. If `False`, the field marked with this annotation is skipped from the
        serialized output. Defaults to `True`.

        Since
        - 1.4
        """
        return True


    def deserialize(self) -> bool:
        """
        If `True`, the field marked with this annotation is deserialized from the JSON.
        If `False`, the field marked with this annotation is skipped during deserialization. 
        Defaults to `True`.

        Since
        - 1.4
        """
        return True



from .Fluid import Fluid
from .WorldBorder import WorldBorder
from .WorldCreator import WorldCreator
from .Utility import Utility
from .SkullType import SkullType
from .GrassSpecies import GrassSpecies
from .CoalType import CoalType
from .FeatureFlag import FeatureFlag
from .WorldType import WorldType
from .UnsafeValues import UnsafeValues
from .Note import Note
from .HeightMap import HeightMap
from .Raid import Raid
from .NetherWartsState import NetherWartsState
from .FireworkEffect import FireworkEffect
from .SoundGroup import SoundGroup
from .Vibration import Vibration
from .Axis import Axis
from .MinecraftExperimental import MinecraftExperimental
from .Registry import Registry
from .FluidCollisionMode import FluidCollisionMode
from .Difficulty import Difficulty
from .MusicInstrument import MusicInstrument
from .Particle import Particle
from .RegionAccessor import RegionAccessor
from .Effect import Effect
from .Statistic import Statistic
from .GameEvent import GameEvent
from .BanEntry import BanEntry
from .StructureType import StructureType
from .Location import Location
from .BanList import BanList
from .ChunkSnapshot import ChunkSnapshot
from .UndefinedNullability import UndefinedNullability
from .Keyed import Keyed
from .NamespacedKey import NamespacedKey
from .SoundCategory import SoundCategory
from .DyeColor import DyeColor
from .Chunk import Chunk
from .SandstoneType import SandstoneType
from .GameMode import GameMode
from .CropState import CropState
from .Tag import Tag
from .OfflinePlayer import OfflinePlayer
from .ServerTickManager import ServerTickManager
from .GameRule import GameRule
from .Sound import Sound
from .Translatable import Translatable
from .EntityEffect import EntityEffect
from .Instrument import Instrument
from .ChatColor import ChatColor
from .Art import Art
from .PortalType import PortalType
from .World import World
from .Rotation import Rotation
from .WeatherType import WeatherType
from .Server import Server
from .Material import Material
from .TreeSpecies import TreeSpecies
from .Nameable import Nameable
from .Warning import Warning
from .TreeType import TreeType
from .Bukkit import Bukkit
from .Color import Color
from .BlockChangeDelegate import BlockChangeDelegate


"""
Python module generated from Java source file org.bukkit.material.NetherWarts

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit import NetherWartsState
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class NetherWarts(MaterialData):
    """
    Represents nether wart

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self):
        ...


    def __init__(self, state: "NetherWartsState"):
        ...


    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def getState(self) -> "NetherWartsState":
        """
        Gets the current growth state of this nether wart

        Returns
        - NetherWartsState of this nether wart
        """
        ...


    def setState(self, state: "NetherWartsState") -> None:
        """
        Sets the growth state of this nether wart

        Arguments
        - state: New growth state of this nether wart
        """
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "NetherWarts":
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableSortedSetFauxverideShim

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import DoNotCall
from java.util.stream import Collector
from typing import Any, Callable, Iterable, Tuple


class ImmutableSortedSetFauxverideShim(CachingAsList):
    """
    "Overrides" the ImmutableSet static methods that lack ImmutableSortedSet
    equivalents with deprecated, exception-throwing versions. This prevents accidents like the
    following:
    
    ````List<Object> objects = ...;
    // Sort them:
    Set<Object> sorted = ImmutableSortedSet.copyOf(objects);
    // BAD CODE! The returned set is actually an unsorted ImmutableSet!````
    
    While we could put the overrides in ImmutableSortedSet itself, it seems clearer to
    separate these "do not call" methods from those intended for normal use.

    Author(s)
    - Chris Povirk
    """

    @staticmethod
    def toImmutableSet() -> "Collector"["E", Any, "ImmutableSet"["E"]]:
        """
        Not supported. Use ImmutableSortedSet.toImmutableSortedSet instead. This method exists
        only to hide ImmutableSet.toImmutableSet from consumers of `ImmutableSortedSet`.

        Raises
        - UnsupportedOperationException: always

        Since
        - 21.0

        Deprecated
        - Use ImmutableSortedSet.toImmutableSortedSet.
        """
        ...


    @staticmethod
    def builder() -> "ImmutableSortedSet.Builder"["E"]:
        """
        Not supported. Use ImmutableSortedSet.naturalOrder, which offers better type-safety,
        instead. This method exists only to hide ImmutableSet.builder from consumers of `ImmutableSortedSet`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Use ImmutableSortedSet.naturalOrder, which offers better type-safety.
        """
        ...


    @staticmethod
    def builderWithExpectedSize(expectedSize: int) -> "ImmutableSortedSet.Builder"["E"]:
        """
        Not supported. This method exists only to hide ImmutableSet.builderWithExpectedSize
        from consumers of `ImmutableSortedSet`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Not supported by ImmutableSortedSet.
        """
        ...


    @staticmethod
    def of(element: "E") -> "ImmutableSortedSet"["E"]:
        """
        Not supported. **You are attempting to create a set that may contain a non-`Comparable`
        element.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass a parameter of type `Comparable` to use ImmutableSortedSet.of(Comparable).**
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E") -> "ImmutableSortedSet"["E"]:
        """
        Not supported. **You are attempting to create a set that may contain a non-`Comparable`
        element.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedSet.of(Comparable, Comparable).**
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E") -> "ImmutableSortedSet"["E"]:
        """
        Not supported. **You are attempting to create a set that may contain a non-`Comparable`
        element.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedSet.of(Comparable, Comparable, Comparable).**
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E") -> "ImmutableSortedSet"["E"]:
        """
        Not supported. **You are attempting to create a set that may contain a non-`Comparable`
        element.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedSet.of(Comparable, Comparable, Comparable, Comparable). **
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E") -> "ImmutableSortedSet"["E"]:
        """
        Not supported. **You are attempting to create a set that may contain a non-`Comparable`
        element.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedSet.of( Comparable, Comparable, Comparable, Comparable, Comparable). **
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E", e6: "E", *remaining: Tuple["E", ...]) -> "ImmutableSortedSet"["E"]:
        """
        Not supported. **You are attempting to create a set that may contain a non-`Comparable`
        element.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedSet.of(Comparable, Comparable, Comparable, Comparable, Comparable,
            Comparable, Comparable...). **
        """
        ...


    @staticmethod
    def copyOf(elements: list["E"]) -> "ImmutableSortedSet"["E"]:
        """
        Not supported. **You are attempting to create a set that may contain non-`Comparable`
        elements.** Proper calls will resolve to the version in `ImmutableSortedSet`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass parameters of type `Comparable` to use ImmutableSortedSet.copyOf(Comparable[]).**
        """
        ...



"""
Python module generated from Java source file org.bukkit.attribute.Attribute

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import Bukkit
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit import Translatable
from org.bukkit.attribute import *
from typing import Any, Callable, Iterable, Tuple


class Attribute(Enum):
    """
    Types of attributes which may be present on an Attributable.
    """

    GENERIC_MAX_HEALTH = ("generic.max_health")
    """
    Maximum health of an Entity.
    """
    GENERIC_FOLLOW_RANGE = ("generic.follow_range")
    """
    Range at which an Entity will follow others.
    """
    GENERIC_KNOCKBACK_RESISTANCE = ("generic.knockback_resistance")
    """
    Resistance of an Entity to knockback.
    """
    GENERIC_MOVEMENT_SPEED = ("generic.movement_speed")
    """
    Movement speed of an Entity.
    """
    GENERIC_FLYING_SPEED = ("generic.flying_speed")
    """
    Flying speed of an Entity.
    """
    GENERIC_ATTACK_DAMAGE = ("generic.attack_damage")
    """
    Attack damage of an Entity.
    """
    GENERIC_ATTACK_KNOCKBACK = ("generic.attack_knockback")
    """
    Attack knockback of an Entity.
    """
    GENERIC_ATTACK_SPEED = ("generic.attack_speed")
    """
    Attack speed of an Entity.
    """
    GENERIC_ARMOR = ("generic.armor")
    """
    Armor bonus of an Entity.
    """
    GENERIC_ARMOR_TOUGHNESS = ("generic.armor_toughness")
    """
    Armor durability bonus of an Entity.
    """
    GENERIC_LUCK = ("generic.luck")
    """
    Luck bonus of an Entity.
    """
    GENERIC_MAX_ABSORPTION = ("generic.max_absorption")
    """
    Maximum absorption of an Entity.
    """
    HORSE_JUMP_STRENGTH = ("horse.jump_strength")
    """
    Strength with which a horse will jump.
    """
    ZOMBIE_SPAWN_REINFORCEMENTS = ("zombie.spawn_reinforcements")
    """
    Chance of a zombie to spawn reinforcements.
    """


    def getKey(self) -> "NamespacedKey":
        ...


    def getTranslationKey(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.entity.Sheep

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from org.bukkit.material import Colorable
from typing import Any, Callable, Iterable, Tuple


class Sheep(Animals, Colorable):
    """
    Represents a Sheep.
    """

    def isSheared(self) -> bool:
        """
        Returns
        - Whether the sheep is sheared.
        """
        ...


    def setSheared(self, flag: bool) -> None:
        """
        Arguments
        - flag: Whether to shear the sheep
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.trim.TrimPattern

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Keyed
from org.bukkit import Material
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit import Translatable
from org.bukkit.inventory.meta.trim import *
from typing import Any, Callable, Iterable, Tuple


class TrimPattern(Keyed, Translatable):
    """
    Represents a pattern that may be used in an ArmorTrim.
    """

    SENTRY = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("sentry"))
    """
    Material.SENTRY_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    DUNE = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("dune"))
    """
    Material.DUNE_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    COAST = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("coast"))
    """
    Material.COAST_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    WILD = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("wild"))
    """
    Material.WILD_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    WARD = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("ward"))
    """
    Material.WARD_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    EYE = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("eye"))
    """
    Material.EYE_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    VEX = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("vex"))
    """
    Material.VEX_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    TIDE = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("tide"))
    """
    Material.TIDE_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    SNOUT = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("snout"))
    """
    Material.SNOUT_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    RIB = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("rib"))
    """
    Material.RIB_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    SPIRE = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("spire"))
    """
    Material.SPIRE_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    WAYFINDER = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("wayfinder"))
    """
    Material.WAYFINDER_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    SHAPER = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("shaper"))
    """
    Material.SHAPER_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    SILENCE = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("silence"))
    """
    Material.SILENCE_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    RAISER = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("raiser"))
    """
    Material.RAISER_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    HOST = Registry.TRIM_PATTERN.get(NamespacedKey.minecraft("host"))
    """
    Material.HOST_ARMOR_TRIM_SMITHING_TEMPLATE.
    """



"""
Python module generated from Java source file org.bukkit.potion.Potion

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from org.bukkit import Material
from org.bukkit.entity import LivingEntity
from org.bukkit.inventory import ItemStack
from org.bukkit.inventory.meta import PotionMeta
from org.bukkit.potion import *
from typing import Any, Callable, Iterable, Tuple


class Potion:
    """
    Potion Adapter for pre-1.9 data values
    see @PotionMeta for 1.9+
    """

    def __init__(self, type: "PotionType"):
        """
        Construct a new potion of the given type. Unless the type is PotionType.WATER, it will be level one, without extended duration.
        Don't use this constructor to create a no-effect potion other than
        water bottle.

        Arguments
        - type: The potion type
        """
        ...


    def __init__(self, type: "PotionType", level: int):
        """
        Create a new potion of the given type and level.

        Arguments
        - type: The type of potion.
        - level: The potion's level.
        """
        ...


    def __init__(self, type: "PotionType", level: int, splash: bool):
        """
        Create a new potion of the given type and level.

        Arguments
        - type: The type of potion.
        - level: The potion's level.
        - splash: Whether it is a splash potion.

        Deprecated
        - In favour of using .Potion(PotionType) with .splash().
        """
        ...


    def __init__(self, type: "PotionType", level: int, splash: bool, extended: bool):
        """
        Create a new potion of the given type and level.

        Arguments
        - type: The type of potion.
        - level: The potion's level.
        - splash: Whether it is a splash potion.
        - extended: Whether it has an extended duration.

        Deprecated
        - In favour of using .Potion(PotionType) with .extend() and possibly .splash().
        """
        ...


    def splash(self) -> "Potion":
        """
        Chain this to the constructor to make the potion a splash potion.

        Returns
        - The potion.
        """
        ...


    def extend(self) -> "Potion":
        """
        Chain this to the constructor to extend the potion's duration.

        Returns
        - The potion.
        """
        ...


    def apply(self, to: "ItemStack") -> None:
        """
        Applies the effects of this potion to the given ItemStack. The
        ItemStack must be a potion.

        Arguments
        - to: The itemstack to apply to
        """
        ...


    def apply(self, to: "LivingEntity") -> None:
        """
        Applies the effects that would be applied by this potion to the given
        LivingEntity.

        Arguments
        - to: The entity to apply the effects to

        See
        - LivingEntity.addPotionEffects(Collection)
        """
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def getEffects(self) -> Iterable["PotionEffect"]:
        """
        Returns a collection of PotionEffects that this Potion
        would confer upon a LivingEntity.

        Returns
        - The effects that this potion applies

        See
        - Potion.toDamageValue()
        """
        ...


    def getLevel(self) -> int:
        """
        Returns the level of this potion.

        Returns
        - The level of this potion
        """
        ...


    def getType(self) -> "PotionType":
        """
        Returns the PotionType of this potion.

        Returns
        - The type of this potion
        """
        ...


    def hasExtendedDuration(self) -> bool:
        """
        Returns whether this potion has an extended duration.

        Returns
        - Whether this potion has extended duration
        """
        ...


    def hashCode(self) -> int:
        ...


    def isSplash(self) -> bool:
        """
        Returns whether this potion is a splash potion.

        Returns
        - Whether this is a splash potion
        """
        ...


    def setHasExtendedDuration(self, isExtended: bool) -> None:
        """
        Set whether this potion has extended duration. This will cause the
        potion to have roughly 8/3 more duration than a regular potion.

        Arguments
        - isExtended: Whether the potion should have extended duration
        """
        ...


    def setSplash(self, isSplash: bool) -> None:
        """
        Sets whether this potion is a splash potion. Splash potions can be
        thrown for a radius effect.

        Arguments
        - isSplash: Whether this is a splash potion
        """
        ...


    def setType(self, type: "PotionType") -> None:
        """
        Sets the PotionType of this potion.

        Arguments
        - type: The new type of this potion
        """
        ...


    def setLevel(self, level: int) -> None:
        """
        Sets the level of this potion.

        Arguments
        - level: The new level of this potion
        """
        ...


    def toDamageValue(self) -> int:
        """
        Converts this potion to a valid potion damage short, usable for potion
        item stacks.

        Returns
        - The damage value of this potion

        Deprecated
        - Non-functional
        """
        ...


    def toItemStack(self, amount: int) -> "ItemStack":
        """
        Converts this potion to an ItemStack with the specified amount
        and a correct damage value.

        Arguments
        - amount: The amount of the ItemStack

        Returns
        - The created ItemStack
        """
        ...


    @staticmethod
    def fromDamage(damage: int) -> "Potion":
        """
        Gets the potion from its damage value.

        Arguments
        - damage: the damage value

        Returns
        - the produced potion
        """
        ...


    @staticmethod
    def fromItemStack(item: "ItemStack") -> "Potion":
        ...


    @staticmethod
    def getBrewer() -> "PotionBrewer":
        """
        Returns an instance of PotionBrewer.

        Returns
        - An instance of PotionBrewer
        """
        ...


    @staticmethod
    def setPotionBrewer(other: "PotionBrewer") -> None:
        """
        Sets the current instance of PotionBrewer. Generally not to be
        used from within a plugin.

        Arguments
        - other: The new PotionBrewer
        """
        ...


    def getNameId(self) -> int:
        """
        Gets the potion from its name id.

        Returns
        - the name id

        Deprecated
        - Non-functional
        """
        ...



from .Messenger import Messenger
from .ChannelNameTooLongException import ChannelNameTooLongException
from .PluginMessageRecipient import PluginMessageRecipient
from .ReservedChannelException import ReservedChannelException
from .PluginChannelDirection import PluginChannelDirection
from .ChannelNotRegisteredException import ChannelNotRegisteredException
from .PluginMessageListenerRegistration import PluginMessageListenerRegistration
from .MessageTooLargeException import MessageTooLargeException
from .StandardMessenger import StandardMessenger
from .PluginMessageListener import PluginMessageListener


from .InventoryAction import InventoryAction
from .FurnaceSmeltEvent import FurnaceSmeltEvent
from .DragType import DragType
from .BrewEvent import BrewEvent
from .InventoryCreativeEvent import InventoryCreativeEvent
from .InventoryInteractEvent import InventoryInteractEvent
from .InventoryType import InventoryType
from .InventoryEvent import InventoryEvent
from .BrewingStandFuelEvent import BrewingStandFuelEvent
from .CraftItemEvent import CraftItemEvent
from .FurnaceStartSmeltEvent import FurnaceStartSmeltEvent
from .FurnaceBurnEvent import FurnaceBurnEvent
from .PrepareInventoryResultEvent import PrepareInventoryResultEvent
from .InventoryDragEvent import InventoryDragEvent
from .ClickType import ClickType
from .SmithItemEvent import SmithItemEvent
from .HopperInventorySearchEvent import HopperInventorySearchEvent
from .InventoryPickupItemEvent import InventoryPickupItemEvent
from .InventoryCloseEvent import InventoryCloseEvent
from .PrepareItemCraftEvent import PrepareItemCraftEvent
from .TradeSelectEvent import TradeSelectEvent
from .PrepareAnvilEvent import PrepareAnvilEvent
from .InventoryClickEvent import InventoryClickEvent
from .FurnaceExtractEvent import FurnaceExtractEvent
from .PrepareSmithingEvent import PrepareSmithingEvent
from .InventoryMoveItemEvent import InventoryMoveItemEvent
from .InventoryOpenEvent import InventoryOpenEvent
from .PrepareGrindstoneEvent import PrepareGrindstoneEvent


from .ThrownExpBottle import ThrownExpBottle
from .Giant import Giant
from .Illager import Illager
from .TropicalFish import TropicalFish
from .Interaction import Interaction
from .Enderman import Enderman
from .Sittable import Sittable
from .Bat import Bat
from .Damageable import Damageable
from .SizedFireball import SizedFireball
from .PolarBear import PolarBear
from .GlowItemFrame import GlowItemFrame
from .Dolphin import Dolphin
from .Tameable import Tameable
from .Evoker import Evoker
from .SpectralArrow import SpectralArrow
from .Blaze import Blaze
from .ZombieVillager import ZombieVillager
from .Horse import Horse
from .Fox import Fox
from .Pose import Pose
from .MushroomCow import MushroomCow
from .BlockDisplay import BlockDisplay
from .Parrot import Parrot
from .Panda import Panda
from .Cod import Cod
from .AbstractArrow import AbstractArrow
from .Breeze import Breeze
from .Camel import Camel
from .Sheep import Sheep
from .PigZombie import PigZombie
from .LargeFireball import LargeFireball
from .Entity import Entity
from .Fish import Fish
from .Ghast import Ghast
from .Player import Player
from .Animals import Animals
from .Chicken import Chicken
from .Mob import Mob
from .EvokerFangs import EvokerFangs
from .Display import Display
from .EnderCrystal import EnderCrystal
from .Donkey import Donkey
from .DragonFireball import DragonFireball
from .ComplexEntityPart import ComplexEntityPart
from .Rabbit import Rabbit
from .Phantom import Phantom
from .Monster import Monster
from .PiglinBrute import PiglinBrute
from .WaterMob import WaterMob
from .LingeringPotion import LingeringPotion
from .ChestedHorse import ChestedHorse
from .Turtle import Turtle
from .Boat import Boat
from .Hanging import Hanging
from .Wolf import Wolf
from .SmallFireball import SmallFireball
from .Squid import Squid
from .Strider import Strider
from .Pig import Pig
from .Illusioner import Illusioner
from .AbstractHorse import AbstractHorse
from .EnderDragonPart import EnderDragonPart
from .Zombie import Zombie
from .Ambient import Ambient
from .TextDisplay import TextDisplay
from .AbstractSkeleton import AbstractSkeleton
from .AnimalTamer import AnimalTamer
from .ComplexLivingEntity import ComplexLivingEntity
from .Flying import Flying
from .Bee import Bee
from .EntityType import EntityType
from .FishHook import FishHook
from .Spellcaster import Spellcaster
from .PufferFish import PufferFish
from .CaveSpider import CaveSpider
from .NPC import NPC
from .ChestBoat import ChestBoat
from .EntityCategory import EntityCategory
from .Wither import Wither
from .AbstractVillager import AbstractVillager
from .EntitySnapshot import EntitySnapshot
from .LightningStrike import LightningStrike
from .Breedable import Breedable
from .TippedArrow import TippedArrow
from .LivingEntity import LivingEntity
from .WitherSkeleton import WitherSkeleton
from .Ravager import Ravager
from .Warden import Warden
from .Firework import Firework
from .GlowSquid import GlowSquid
from .Vehicle import Vehicle
from .ExperienceOrb import ExperienceOrb
from .Llama import Llama
from .Fireball import Fireball
from .ElderGuardian import ElderGuardian
from .ZombieHorse import ZombieHorse
from .LlamaSpit import LlamaSpit
from .Explosive import Explosive
from .ThrowableProjectile import ThrowableProjectile
from .ItemDisplay import ItemDisplay
from .FallingBlock import FallingBlock
from .Snowball import Snowball
from .Sniffer import Sniffer
from .Spider import Spider
from .EnderDragon import EnderDragon
from .Snowman import Snowman
from .Minecart import Minecart
from .Hoglin import Hoglin
from .ArmorStand import ArmorStand
from .SkeletonHorse import SkeletonHorse
from .Trident import Trident
from .ShulkerBullet import ShulkerBullet
from .EnderPearl import EnderPearl
from .ItemFrame import ItemFrame
from .Salmon import Salmon
from .Vindicator import Vindicator
from .EnderSignal import EnderSignal
from .SpawnCategory import SpawnCategory
from .Creature import Creature
from .Cow import Cow
from .Stray import Stray
from .Raider import Raider
from .Enemy import Enemy
from .LeashHitch import LeashHitch
from .Frog import Frog
from .Projectile import Projectile
from .Marker import Marker
from .Steerable import Steerable
from .Cat import Cat
from .Slime import Slime
from .Ageable import Ageable
from .Tadpole import Tadpole
from .Witch import Witch
from .WindCharge import WindCharge
from .Pillager import Pillager
from .Guardian import Guardian
from .WanderingTrader import WanderingTrader
from .TraderLlama import TraderLlama
from .Arrow import Arrow
from .Boss import Boss
from .SplashPotion import SplashPotion
from .Ocelot import Ocelot
from .Villager import Villager
from .Vex import Vex
from .Drowned import Drowned
from .PiglinAbstract import PiglinAbstract
from .HumanEntity import HumanEntity
from .MagmaCube import MagmaCube
from .Husk import Husk
from .Piglin import Piglin
from .IronGolem import IronGolem
from .Silverfish import Silverfish
from .Shulker import Shulker
from .Skeleton import Skeleton
from .WitherSkull import WitherSkull
from .Painting import Painting
from .Mule import Mule
from .Egg import Egg
from .Item import Item
from .Zoglin import Zoglin
from .Creeper import Creeper
from .Goat import Goat
from .ThrownPotion import ThrownPotion
from .Axolotl import Axolotl
from .Golem import Golem
from .TNTPrimed import TNTPrimed
from .Allay import Allay
from .Endermite import Endermite
from .AreaEffectCloud import AreaEffectCloud


"""
Python module generated from Java source file org.bukkit.event.block.BrewingStartEvent

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class BrewingStartEvent(InventoryBlockStartEvent):
    """
    Called when a brewing stand starts to brew.
    """

    def __init__(self, furnace: "Block", source: "ItemStack", brewingTime: int):
        ...


    def getTotalBrewTime(self) -> int:
        """
        Gets the total brew time associated with this event.

        Returns
        - the total brew time
        """
        ...


    def setTotalBrewTime(self, brewTime: int) -> None:
        """
        Sets the total brew time for this event.

        Arguments
        - brewTime: the new total brew time
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



from .Jigsaw import Jigsaw
from .EnchantingTable import EnchantingTable
from .CreatureSpawner import CreatureSpawner
from .TrialSpawner import TrialSpawner
from .Lectern import Lectern
from .Smoker import Smoker
from .Banner import Banner
from .BlockState import BlockState
from .Campfire import Campfire
from .SculkCatalyst import SculkCatalyst
from .BlockFace import BlockFace
from .Skull import Skull
from .Lidded import Lidded
from .EndGateway import EndGateway
from .Container import Container
from .EntityBlockStorage import EntityBlockStorage
from .BrushableBlock import BrushableBlock
from .Barrel import Barrel
from .TileState import TileState
from .Beehive import Beehive
from .Crafter import Crafter
from .Chest import Chest
from .ChiseledBookshelf import ChiseledBookshelf
from .SculkSensor import SculkSensor
from .Beacon import Beacon
from .EnderChest import EnderChest
from .SculkShrieker import SculkShrieker
from .SuspiciousSand import SuspiciousSand
from .BrewingStand import BrewingStand
from .Biome import Biome
from .Dropper import Dropper
from .Structure import Structure
from .Comparator import Comparator
from .CommandBlock import CommandBlock
from .DecoratedPot import DecoratedPot
from .ShulkerBox import ShulkerBox
from .Hopper import Hopper
from .Dispenser import Dispenser
from .BlastFurnace import BlastFurnace
from .Bell import Bell
from .Jukebox import Jukebox
from .Bed import Bed
from .Sign import Sign
from .DoubleChest import DoubleChest
from .Block import Block
from .BlockSupport import BlockSupport
from .PistonMoveReaction import PistonMoveReaction
from .HangingSign import HangingSign
from .CalibratedSculkSensor import CalibratedSculkSensor
from .Furnace import Furnace
from .Lockable import Lockable
from .DaylightDetector import DaylightDetector
from .Conduit import Conduit


from .BlockData import BlockData
from .Attachable import Attachable
from .Snowable import Snowable
from .Waterlogged import Waterlogged
from .Rail import Rail
from .MultipleFacing import MultipleFacing
from .Brushable import Brushable
from .Levelled import Levelled
from .AnaloguePowerable import AnaloguePowerable
from .Hatchable import Hatchable
from .Bisected import Bisected
from .Hangable import Hangable
from .Orientable import Orientable
from .Powerable import Powerable
from .Ageable import Ageable
from .Directional import Directional
from .Rotatable import Rotatable
from .FaceAttachable import FaceAttachable
from .Lightable import Lightable
from .Openable import Openable


"""
Python module generated from Java source file org.bukkit.inventory.AnvilInventory

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class AnvilInventory(Inventory):
    """
    Interface to the inventory of an Anvil.
    """

    def getRenameText(self) -> str:
        """
        Get the name to be applied to the repaired item. An empty string denotes
        the default item name.

        Returns
        - the rename text
        """
        ...


    def getRepairCostAmount(self) -> int:
        """
        Get the item cost (in amount) to complete the current repair.

        Returns
        - the amount
        """
        ...


    def setRepairCostAmount(self, amount: int) -> None:
        """
        Set the item cost (in amount) to complete the current repair.

        Arguments
        - amount: the amount
        """
        ...


    def getRepairCost(self) -> int:
        """
        Get the experience cost (in levels) to complete the current repair.

        Returns
        - the experience cost
        """
        ...


    def setRepairCost(self, levels: int) -> None:
        """
        Set the experience cost (in levels) to complete the current repair.

        Arguments
        - levels: the experience cost
        """
        ...


    def getMaximumRepairCost(self) -> int:
        """
        Get the maximum experience cost (in levels) to be allowed by the current
        repair. If the result of .getRepairCost() exceeds the returned
        value, the repair result will be air to due being "too expensive".
        
        By default, this level is set to 40. Players in creative mode ignore the
        maximum repair cost.

        Returns
        - the maximum experience cost
        """
        ...


    def setMaximumRepairCost(self, levels: int) -> None:
        """
        Set the maximum experience cost (in levels) to be allowed by the current
        repair. The default value set by vanilla Minecraft is 40.

        Arguments
        - levels: the maximum experience cost
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.ColorableArmorMeta

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory.meta import *
from typing import Any, Callable, Iterable, Tuple


class ColorableArmorMeta(ArmorMeta, LeatherArmorMeta):
    """
    Represents armor that an entity can equip and can also be colored.
    """

    def clone(self) -> "ColorableArmorMeta":
        ...



from .RecipeChoice import RecipeChoice
from .StonecuttingRecipe import StonecuttingRecipe
from .InventoryHolder import InventoryHolder
from .ShapedRecipe import ShapedRecipe
from .ChiseledBookshelfInventory import ChiseledBookshelfInventory
from .HorseInventory import HorseInventory
from .CartographyInventory import CartographyInventory
from .ItemStack import ItemStack
from .MerchantInventory import MerchantInventory
from .AnvilInventory import AnvilInventory
from .BlockInventoryHolder import BlockInventoryHolder
from .Recipe import Recipe
from .SmithingTrimRecipe import SmithingTrimRecipe
from .BlastingRecipe import BlastingRecipe
from .FurnaceRecipe import FurnaceRecipe
from .ShapelessRecipe import ShapelessRecipe
from .MerchantRecipe import MerchantRecipe
from .SmithingRecipe import SmithingRecipe
from .GrindstoneInventory import GrindstoneInventory
from .InventoryView import InventoryView
from .CampfireRecipe import CampfireRecipe
from .StonecutterInventory import StonecutterInventory
from .DecoratedPotInventory import DecoratedPotInventory
from .MainHand import MainHand
from .CraftingInventory import CraftingInventory
from .BeaconInventory import BeaconInventory
from .CookingRecipe import CookingRecipe
from .PlayerInventory import PlayerInventory
from .CreativeCategory import CreativeCategory
from .EntityEquipment import EntityEquipment
from .CrafterInventory import CrafterInventory
from .SmokingRecipe import SmokingRecipe
from .LlamaInventory import LlamaInventory
from .Inventory import Inventory
from .ItemCraftResult import ItemCraftResult
from .LecternInventory import LecternInventory
from .DoubleChestInventory import DoubleChestInventory
from .JukeboxInventory import JukeboxInventory
from .EnchantingInventory import EnchantingInventory
from .Merchant import Merchant
from .SmithingTransformRecipe import SmithingTransformRecipe
from .SmithingInventory import SmithingInventory
from .FurnaceInventory import FurnaceInventory
from .BrewerInventory import BrewerInventory
from .ComplexRecipe import ComplexRecipe
from .EquipmentSlot import EquipmentSlot
from .ItemFlag import ItemFlag
from .ItemFactory import ItemFactory
from .AbstractHorseInventory import AbstractHorseInventory
from .LoomInventory import LoomInventory
from .CraftingRecipe import CraftingRecipe


"""
Python module generated from Java source file org.bukkit.entity.Fireball

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from org.bukkit.util import Vector
from typing import Any, Callable, Iterable, Tuple


class Fireball(Projectile, Explosive):
    """
    Represents a Fireball.
    """

    def setDirection(self, direction: "Vector") -> None:
        """
        Fireballs fly straight and do not take setVelocity(...) well.

        Arguments
        - direction: the direction this fireball is flying toward
        """
        ...


    def getDirection(self) -> "Vector":
        """
        Retrieve the direction this fireball is heading toward

        Returns
        - the direction
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.block.BlockExplodeEvent

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class BlockExplodeEvent(BlockEvent, Cancellable):
    """
    Called when a block explodes
    """

    def __init__(self, what: "Block", blocks: list["Block"], yield: float):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def blockList(self) -> list["Block"]:
        """
        Returns the list of blocks that would have been removed or were removed
        from the explosion event.

        Returns
        - All blown-up blocks
        """
        ...


    def getYield(self) -> float:
        """
        Returns the percentage of blocks to drop from this explosion

        Returns
        - The yield.
        """
        ...


    def setYield(self, yield: float) -> None:
        """
        Sets the percentage of blocks to drop from this explosion

        Arguments
        - yield: The new yield percentage
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.Fluid

Java source file obtained from artifact spigot-api version 1.20.4-R0.1-20240423.152506-123

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.util import Locale
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class Fluid(Enum):
    """
    Represents a fluid type.
    """

    WATER = 0
    """
    Stationary water.
    """
    FLOWING_WATER = 1
    """
    Flowing water.
    """
    LAVA = 2
    """
    Stationary lava.
    """
    FLOWING_LAVA = 3
    """
    Flowing lava.
    """


    def getKey(self) -> "NamespacedKey":
        ...



from .SqlTimestampTypeAdapter import SqlTimestampTypeAdapter
from .SqlDateTypeAdapter import SqlDateTypeAdapter
from .SqlTypesSupport import SqlTypesSupport
from .SqlTimeTypeAdapter import SqlTimeTypeAdapter


from .JsonTreeWriter import JsonTreeWriter
from .JsonTreeReader import JsonTreeReader
from .ObjectTypeAdapter import ObjectTypeAdapter
from .ArrayTypeAdapter import ArrayTypeAdapter
from .JsonAdapterAnnotationTypeAdapterFactory import JsonAdapterAnnotationTypeAdapterFactory
from .TypeAdapters import TypeAdapters
from .SerializationDelegatingTypeAdapter import SerializationDelegatingTypeAdapter
from .NumberTypeAdapter import NumberTypeAdapter
from .CollectionTypeAdapterFactory import CollectionTypeAdapterFactory
from .ReflectiveTypeAdapterFactory import ReflectiveTypeAdapterFactory
from .DefaultDateTypeAdapter import DefaultDateTypeAdapter
from .TreeTypeAdapter import TreeTypeAdapter
from .MapTypeAdapterFactory import MapTypeAdapterFactory
from .TypeAdapterRuntimeTypeWrapper import TypeAdapterRuntimeTypeWrapper
from .DateTypeAdapter import DateTypeAdapter


from .RemoteServerCommandEvent import RemoteServerCommandEvent
from .PluginEvent import PluginEvent
from .BroadcastMessageEvent import BroadcastMessageEvent
from .MapInitializeEvent import MapInitializeEvent
from .ServerCommandEvent import ServerCommandEvent
from .PluginDisableEvent import PluginDisableEvent
from .ServiceRegisterEvent import ServiceRegisterEvent
from .ServerEvent import ServerEvent
from .ServerListPingEvent import ServerListPingEvent
from .ServiceUnregisterEvent import ServiceUnregisterEvent
from .ServiceEvent import ServiceEvent
from .PluginEnableEvent import PluginEnableEvent
from .ServerLoadEvent import ServerLoadEvent
from .TabCompleteEvent import TabCompleteEvent


from .PortalCreateEvent import PortalCreateEvent
from .ChunkPopulateEvent import ChunkPopulateEvent
from .AsyncStructureSpawnEvent import AsyncStructureSpawnEvent
from .LootGenerateEvent import LootGenerateEvent
from .StructureGrowEvent import StructureGrowEvent
from .EntitiesLoadEvent import EntitiesLoadEvent
from .ChunkLoadEvent import ChunkLoadEvent
from .ChunkUnloadEvent import ChunkUnloadEvent
from .WorldInitEvent import WorldInitEvent
from .WorldEvent import WorldEvent
from .WorldUnloadEvent import WorldUnloadEvent
from .GenericGameEvent import GenericGameEvent
from .EntitiesUnloadEvent import EntitiesUnloadEvent
from .WorldSaveEvent import WorldSaveEvent
from .ChunkEvent import ChunkEvent
from .TimeSkipEvent import TimeSkipEvent
from .SpawnChangeEvent import SpawnChangeEvent
from .WorldLoadEvent import WorldLoadEvent
from .AsyncStructureGenerateEvent import AsyncStructureGenerateEvent